@@ -7,13 +7,150 @@ set -o errexit
 # Baldur's Gate 3
 ###
 
-script_version=20240106.1
+script_version=20240531.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.29'
 
 GAME_ID='baldurs-gate-3'
 GAME_NAME='Baldurʼs Gate Ⅲ'
 
+ARCHIVE_BASE_PATCH6_0_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689).exe'
+ARCHIVE_BASE_PATCH6_0_MD5='1adeda86e51f6dd711059c27e8d5224f'
+ARCHIVE_BASE_PATCH6_0_TYPE='innosetup'
+ARCHIVE_BASE_PATCH6_0_PART1_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-1.bin'
+ARCHIVE_BASE_PATCH6_0_PART1_MD5='c4274fcae2412d61045b986fa1368ed4'
+ARCHIVE_BASE_PATCH6_0_PART2_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-2.bin'
+ARCHIVE_BASE_PATCH6_0_PART2_MD5='d69c73883f75b5e40888b6bb218fb5fd'
+ARCHIVE_BASE_PATCH6_0_PART3_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-3.bin'
+ARCHIVE_BASE_PATCH6_0_PART3_MD5='fb8254fc7e30d46c6150dcf065651a1e'
+ARCHIVE_BASE_PATCH6_0_PART4_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-4.bin'
+ARCHIVE_BASE_PATCH6_0_PART4_MD5='304db0f5a987953c987eca014544fd56'
+ARCHIVE_BASE_PATCH6_0_PART5_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-5.bin'
+ARCHIVE_BASE_PATCH6_0_PART5_MD5='417ef6d694d4247f6d71e60ee0e90a65'
+ARCHIVE_BASE_PATCH6_0_PART6_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-6.bin'
+ARCHIVE_BASE_PATCH6_0_PART6_MD5='8c8a6f514debdd9088fe303c1297ab06'
+ARCHIVE_BASE_PATCH6_0_PART7_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-7.bin'
+ARCHIVE_BASE_PATCH6_0_PART7_MD5='7eeebee2ce06232bd75370172bdbb3ec'
+ARCHIVE_BASE_PATCH6_0_PART8_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-8.bin'
+ARCHIVE_BASE_PATCH6_0_PART8_MD5='70b3c3910424e753c49effc573fb52cd'
+ARCHIVE_BASE_PATCH6_0_PART9_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-9.bin'
+ARCHIVE_BASE_PATCH6_0_PART9_MD5='4ee21874b53da4039d946b2c8dcde9ea'
+ARCHIVE_BASE_PATCH6_0_PART10_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-10.bin'
+ARCHIVE_BASE_PATCH6_0_PART10_MD5='2f0403a69a7e968ab52c89aca56ffee7'
+ARCHIVE_BASE_PATCH6_0_PART11_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-11.bin'
+ARCHIVE_BASE_PATCH6_0_PART11_MD5='8168954995979ba3259ef515ac1399e6'
+ARCHIVE_BASE_PATCH6_0_PART12_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-12.bin'
+ARCHIVE_BASE_PATCH6_0_PART12_MD5='b1ed340641bb988cfe412c9c1f729f12'
+ARCHIVE_BASE_PATCH6_0_PART13_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-13.bin'
+ARCHIVE_BASE_PATCH6_0_PART13_MD5='831e762e66bcf2cf20a8434f35d1cc27'
+ARCHIVE_BASE_PATCH6_0_PART14_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-14.bin'
+ARCHIVE_BASE_PATCH6_0_PART14_MD5='be44bad0b9eb5cf649e3568f473b1331'
+ARCHIVE_BASE_PATCH6_0_PART15_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-15.bin'
+ARCHIVE_BASE_PATCH6_0_PART15_MD5='2140db0a5068b86d329bc55c26d4e822'
+ARCHIVE_BASE_PATCH6_0_PART16_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-16.bin'
+ARCHIVE_BASE_PATCH6_0_PART16_MD5='ed03595ca67160d089c305fb4c9bde3d'
+ARCHIVE_BASE_PATCH6_0_PART17_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-17.bin'
+ARCHIVE_BASE_PATCH6_0_PART17_MD5='0a0b02e5ba1a6079a038e0437afd1f2f'
+ARCHIVE_BASE_PATCH6_0_PART18_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-18.bin'
+ARCHIVE_BASE_PATCH6_0_PART18_MD5='aeb62197de4f69c0a019c391f3a7e3c3'
+ARCHIVE_BASE_PATCH6_0_PART19_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-19.bin'
+ARCHIVE_BASE_PATCH6_0_PART19_MD5='7fcf7864a1118e818c7de8362a88e5d2'
+ARCHIVE_BASE_PATCH6_0_PART20_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-20.bin'
+ARCHIVE_BASE_PATCH6_0_PART20_MD5='08cb9545c8f7e032a3dbabb6a24a363c'
+ARCHIVE_BASE_PATCH6_0_PART21_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-21.bin'
+ARCHIVE_BASE_PATCH6_0_PART21_MD5='fb6376493dba115a7c674899fddf28ce'
+ARCHIVE_BASE_PATCH6_0_PART22_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-22.bin'
+ARCHIVE_BASE_PATCH6_0_PART22_MD5='c4e8ac5364bc37eba2df4915439085f8'
+ARCHIVE_BASE_PATCH6_0_PART23_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-23.bin'
+ARCHIVE_BASE_PATCH6_0_PART23_MD5='a894d6a54bdc26ca8bcefd2554dedec9'
+ARCHIVE_BASE_PATCH6_0_PART24_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-24.bin'
+ARCHIVE_BASE_PATCH6_0_PART24_MD5='b422de0996ffb51c75ff00cf167c79cd'
+ARCHIVE_BASE_PATCH6_0_PART25_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-25.bin'
+ARCHIVE_BASE_PATCH6_0_PART25_MD5='4149e5c36d40b7bb0d00a1e99990ae2f'
+ARCHIVE_BASE_PATCH6_0_PART26_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-26.bin'
+ARCHIVE_BASE_PATCH6_0_PART26_MD5='da645662e22d6a56408c002c1a21d80e'
+ARCHIVE_BASE_PATCH6_0_PART27_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-27.bin'
+ARCHIVE_BASE_PATCH6_0_PART27_MD5='2e9e7ad933f31a6932a03cc96683996e'
+ARCHIVE_BASE_PATCH6_0_PART28_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-28.bin'
+ARCHIVE_BASE_PATCH6_0_PART28_MD5='534def45ff6461622c6ad00b1896064c'
+ARCHIVE_BASE_PATCH6_0_PART29_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-29.bin'
+ARCHIVE_BASE_PATCH6_0_PART29_MD5='969580653831dd9300a0140f956ba075'
+ARCHIVE_BASE_PATCH6_0_PART30_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-30.bin'
+ARCHIVE_BASE_PATCH6_0_PART30_MD5='bd384da9ed9589b42afe2bafdf16f84d'
+ARCHIVE_BASE_PATCH6_0_PART31_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-31.bin'
+ARCHIVE_BASE_PATCH6_0_PART31_MD5='6947e03d8f686bdde5e384b7b3443a30'
+ARCHIVE_BASE_PATCH6_0_PART32_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4890942_-_patch_patch6_hotfix4__(64bit)_(71689)-32.bin'
+ARCHIVE_BASE_PATCH6_0_PART32_MD5='c47aeb4934f076c85240bc5e1d42a59c'
+ARCHIVE_BASE_PATCH6_0_SIZE='149344069'
+ARCHIVE_BASE_PATCH6_0_VERSION='4.1.1.4890942-gog71689'
+ARCHIVE_BASE_PATCH6_0_URL='https://www.gog.com/game/baldurs_gate_iii'
+
+ARCHIVE_BASE_PATCH5_1_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408).exe'
+ARCHIVE_BASE_PATCH5_1_MD5='41d296389ec755596846312c290188ba'
+ARCHIVE_BASE_PATCH5_1_TYPE='innosetup'
+ARCHIVE_BASE_PATCH5_1_PART1_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-1.bin'
+ARCHIVE_BASE_PATCH5_1_PART1_MD5='ebbff6fbb2a38f555a30fe8e5c1a8b31'
+ARCHIVE_BASE_PATCH5_1_PART2_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-2.bin'
+ARCHIVE_BASE_PATCH5_1_PART2_MD5='a6577500e4ae2df79027a3aab47180ce'
+ARCHIVE_BASE_PATCH5_1_PART3_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-3.bin'
+ARCHIVE_BASE_PATCH5_1_PART3_MD5='413949288793c7ef6e7576cb573e6561'
+ARCHIVE_BASE_PATCH5_1_PART4_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-4.bin'
+ARCHIVE_BASE_PATCH5_1_PART4_MD5='ba3b2132916fb1a9924668e9c121eacd'
+ARCHIVE_BASE_PATCH5_1_PART5_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-5.bin'
+ARCHIVE_BASE_PATCH5_1_PART5_MD5='2833f2573f0c231eace28e5d55cdf760'
+ARCHIVE_BASE_PATCH5_1_PART6_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-6.bin'
+ARCHIVE_BASE_PATCH5_1_PART6_MD5='a14412e73266f5284fe3512f8531d5d6'
+ARCHIVE_BASE_PATCH5_1_PART7_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-7.bin'
+ARCHIVE_BASE_PATCH5_1_PART7_MD5='598fb783c55f0e750ce0dc9ff33d4e91'
+ARCHIVE_BASE_PATCH5_1_PART8_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-8.bin'
+ARCHIVE_BASE_PATCH5_1_PART8_MD5='4f15395994841e57ab238a417ad19f76'
+ARCHIVE_BASE_PATCH5_1_PART9_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-9.bin'
+ARCHIVE_BASE_PATCH5_1_PART9_MD5='3e0aeed6e2f499b74889600415bbbee8'
+ARCHIVE_BASE_PATCH5_1_PART10_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-10.bin'
+ARCHIVE_BASE_PATCH5_1_PART10_MD5='bf3b28a6d1c8210cff15a0a49d4c3773'
+ARCHIVE_BASE_PATCH5_1_PART11_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-11.bin'
+ARCHIVE_BASE_PATCH5_1_PART11_MD5='fa4fd60332c20e30217197f58e4bbf1b'
+ARCHIVE_BASE_PATCH5_1_PART12_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-12.bin'
+ARCHIVE_BASE_PATCH5_1_PART12_MD5='d00c210e621ab8163a36ca5973d3b8af'
+ARCHIVE_BASE_PATCH5_1_PART13_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-13.bin'
+ARCHIVE_BASE_PATCH5_1_PART13_MD5='80208dd51f3b41543b34b8a08c611bd8'
+ARCHIVE_BASE_PATCH5_1_PART14_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-14.bin'
+ARCHIVE_BASE_PATCH5_1_PART14_MD5='130710e4e6c422769453b7949a783f85'
+ARCHIVE_BASE_PATCH5_1_PART15_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-15.bin'
+ARCHIVE_BASE_PATCH5_1_PART15_MD5='bfc6635ab6f90b5168f67b88d3f7b57a'
+ARCHIVE_BASE_PATCH5_1_PART16_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-16.bin'
+ARCHIVE_BASE_PATCH5_1_PART16_MD5='84f39956129ff4e43c5dbe61a316315a'
+ARCHIVE_BASE_PATCH5_1_PART17_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-17.bin'
+ARCHIVE_BASE_PATCH5_1_PART17_MD5='fb05f610719dfed7278af617d70093e0'
+ARCHIVE_BASE_PATCH5_1_PART18_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-18.bin'
+ARCHIVE_BASE_PATCH5_1_PART18_MD5='40495dfc26875491f29eadeabeb77308'
+ARCHIVE_BASE_PATCH5_1_PART19_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-19.bin'
+ARCHIVE_BASE_PATCH5_1_PART19_MD5='d428eecb383c1317570ef4f9663045c8'
+ARCHIVE_BASE_PATCH5_1_PART20_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-20.bin'
+ARCHIVE_BASE_PATCH5_1_PART20_MD5='cdb6f938deb3ce2bc122f9effcc489b7'
+ARCHIVE_BASE_PATCH5_1_PART21_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-21.bin'
+ARCHIVE_BASE_PATCH5_1_PART21_MD5='6cbcaa9b7c412231b592b436f4e5b77a'
+ARCHIVE_BASE_PATCH5_1_PART22_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-22.bin'
+ARCHIVE_BASE_PATCH5_1_PART22_MD5='a68accd6f697dc9c7542441ce4373c5f'
+ARCHIVE_BASE_PATCH5_1_PART23_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-23.bin'
+ARCHIVE_BASE_PATCH5_1_PART23_MD5='67045ba580bfe38320d046caebf82799'
+ARCHIVE_BASE_PATCH5_1_PART24_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-24.bin'
+ARCHIVE_BASE_PATCH5_1_PART24_MD5='77d5c61d647007d6c2ee522d82354c10'
+ARCHIVE_BASE_PATCH5_1_PART25_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-25.bin'
+ARCHIVE_BASE_PATCH5_1_PART25_MD5='17db3c1c0706d86d074bad776401dfae'
+ARCHIVE_BASE_PATCH5_1_PART26_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-26.bin'
+ARCHIVE_BASE_PATCH5_1_PART26_MD5='6dc6d4ef5c7b3c6fdef926c1dbb79abe'
+ARCHIVE_BASE_PATCH5_1_PART27_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-27.bin'
+ARCHIVE_BASE_PATCH5_1_PART27_MD5='15d16729ba8fd25eaf3fe95bcfd89863'
+ARCHIVE_BASE_PATCH5_1_PART28_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-28.bin'
+ARCHIVE_BASE_PATCH5_1_PART28_MD5='51458a5835f079f452fbb32e57fe29d3'
+ARCHIVE_BASE_PATCH5_1_PART29_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-29.bin'
+ARCHIVE_BASE_PATCH5_1_PART29_MD5='771fe718c64fa6bfd9ac57cba1c18d4e'
+ARCHIVE_BASE_PATCH5_1_PART30_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4494476_-_patch_patch5_hotfix6__(64bit)_(70408)-30.bin'
+ARCHIVE_BASE_PATCH5_1_PART30_MD5='9d1e8c2dde7c7e8d7be9684a1d2936dc'
+ARCHIVE_BASE_PATCH5_1_SIZE='144316256'
+ARCHIVE_BASE_PATCH5_1_VERSION='4.1.1.4494476-gog70408'
+
 ARCHIVE_BASE_PATCH5_0_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888).exe'
 ARCHIVE_BASE_PATCH5_0_MD5='6862e7a492de45b737d78e08c281a511'
 ARCHIVE_BASE_PATCH5_0_TYPE='innosetup'
@@ -79,7 +216,6 @@ ARCHIVE_BASE_PATCH5_0_PART30_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417
 ARCHIVE_BASE_PATCH5_0_PART30_MD5='9d686af3f1622d30a4636d97614a0e12'
 ARCHIVE_BASE_PATCH5_0_SIZE='144082412'
 ARCHIVE_BASE_PATCH5_0_VERSION='4.1.1.4251417-gog69888'
-ARCHIVE_BASE_PATCH5_0_URL='https://www.gog.com/game/baldurs_gate_iii'
 
 ARCHIVE_BASE_PATCH4_0_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995).exe'
 ARCHIVE_BASE_PATCH4_0_MD5='ab6267432b272ff880127131e7b2f5f3'
@@ -400,7 +536,6 @@ CONTENT_PATH_DEFAULT='.'
 CONTENT_GAME_BIN_FILES='
 bin'
 CONTENT_GAME_L10N_VOICES_FILES='
-data/localization/voice.pak
 data/localization/voicemeta.pak'
 CONTENT_GAME_L10N_COMMON_FILES='
 data/localization/english.pak
@@ -461,6 +596,8 @@ CONTENT_GAME_DATA_PATCH4_FILES='
 data/patch4_hotfix*.pak'
 CONTENT_GAME_DATA_PATCH5_FILES='
 data/patch5_hotfix*.pak'
+CONTENT_GAME_DATA_PATCH6_FILES='
+data/patch6_hotfix*.pak'
 CONTENT_GAME_DATA_FILES='
 data/assets.pak
 data/day0.pak
@@ -477,10 +614,13 @@ data/lowtex.pak
 data/materials.pak
 data/shared.pak'
 
+HUGE_FILES_L10N_VOICES='
+data/localization/voice.pak'
 HUGE_FILES_DATA='
 data/gustav.pak'
 ## The size of sharedsounds.pak goes over the .deb size limit only with patch 5,
-## but ./play.it has no problem "splitting" a file into a single chunk, at the cost of more time spent in post-install scripts.
+## but ./play.it has no problem "splitting" a file into a single chunk,
+## at the cost of more time spent in post-install scripts.
 ## TODO: The library-side implementation of huge files should probably skip files under the size limit,
 ##       putting the whole file into a dedicated package without "splitting" it into a single chunk first.
 HUGE_FILES_DATA_SOUNDS='
@@ -488,17 +628,17 @@ data/sharedsounds.pak'
 ## The _PATCH3 suffix is doubled so this matches:
 ## PKG_DATA_PATCH3 in the context of ARCHIVE_BASE_PATCH3
 ## but does not match:
-## PKG_DATA in the context of ARCHIVE_BASE_PATCH3
+## PKG_DATA in the context of ARCHIVE_BASE_PATCH3.
 HUGE_FILES_DATA_PATCH3_PATCH3='
 data/patch3.pak'
 
 WINE_PERSISTENT_DIRECTORIES="
 users/\${USER}/AppData/Local/Larian Studios/Baldur's Gate 3"
-## mfc140u.dll is required
+## mfc140u.dll is required.
 WINE_WINETRICKS_VERBS='mfc140'
 
 APP_MAIN_EXE='bin/bg3.exe'
-## Run the game binary from its parent directory
+## Run the game binary from its parent directory.
 APP_MAIN_PRERUN='# Run the game binary from its parent directory
 cd "$(dirname "$APP_EXE")"
 APP_EXE=$(basename "$APP_EXE")
@@ -539,6 +679,9 @@ PKG_DATA_PATCH4"
 ## Archives patch4*.pak are dropped with the patch 5 release.
 PACKAGES_LIST_PATCH5="$PACKAGES_LIST_BASE
 PKG_DATA_PATCH5"
+## Archives patch5*.pak are dropped with the patch 6 release.
+PACKAGES_LIST_PATCH6="$PACKAGES_LIST_BASE
+PKG_DATA_PATCH6"
 
 PKG_L10N_COMMON_ID="${GAME_ID}-l10n-common"
 PKG_L10N_COMMON_DESCRIPTION='localizations - shared files'
@@ -616,18 +759,21 @@ PKG_DATA_PATCH2_ID="${PKG_DATA_ID}-patch2"
 PKG_DATA_PATCH3_ID="${PKG_DATA_ID}-patch3"
 PKG_DATA_PATCH4_ID="${PKG_DATA_ID}-patch4"
 PKG_DATA_PATCH5_ID="${PKG_DATA_ID}-patch5"
+PKG_DATA_PATCH6_ID="${PKG_DATA_ID}-patch6"
 PKG_DATA_PATCH0_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch0"
 PKG_DATA_PATCH1_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch1"
 PKG_DATA_PATCH2_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch2"
 PKG_DATA_PATCH3_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch3"
 PKG_DATA_PATCH4_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch4"
 PKG_DATA_PATCH5_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch5"
+PKG_DATA_PATCH6_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch6"
 PKG_DATA_DEPS_PATCH0="${PKG_DATA_DEPS:-} $PKG_DATA_PATCH0_ID"
 PKG_DATA_DEPS_PATCH1="$PKG_DATA_DEPS_PATCH0 $PKG_DATA_PATCH1_ID"
 PKG_DATA_DEPS_PATCH2="$PKG_DATA_DEPS_PATCH1 $PKG_DATA_PATCH2_ID"
 PKG_DATA_DEPS_PATCH3="$PKG_DATA_DEPS_PATCH2 $PKG_DATA_PATCH3_ID"
 PKG_DATA_DEPS_PATCH4="${PKG_DATA_DEPS:-} $PKG_DATA_PATCH4_ID"
 PKG_DATA_DEPS_PATCH5="${PKG_DATA_DEPS:-} $PKG_DATA_PATCH5_ID"
+PKG_DATA_DEPS_PATCH6="${PKG_DATA_DEPS:-} $PKG_DATA_PATCH6_ID"
 ## Archives patch0*.pak, patch1*.pak, patch2*.pak and patch3*.pak are dropped with the patch 4 release.
 PKG_DATA_PATCH4_PROVIDES="
 $PKG_DATA_PATCH0_ID
@@ -639,6 +785,9 @@ ${PKG_DATA_PATCH3_ID}-chunk2"
 ## Archives patch4*.pak are dropped with the patch 5 release.
 PKG_DATA_PATCH5_PROVIDES="$PKG_DATA_PATCH4_PROVIDES
 $PKG_DATA_PATCH4_ID"
+## Archives patch5*.pak are dropped with the patch 6 release.
+PKG_DATA_PATCH6_PROVIDES="$PKG_DATA_PATCH5_PROVIDES
+$PKG_DATA_PATCH5_ID"
 
 PKG_BIN_ARCH='64'
 PKG_BIN_DEPS="$PKG_L10N_ID $PKG_DATA_ID"
@@ -691,14 +840,12 @@ sed --expression="s;${l10n_config_pattern};${l10n_config_replacement_fr};" \
 
 # Include game data
 
-set_current_package 'PKG_DATA'
-icons_inclusion
+content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
 # Write launchers
 
-set_current_package 'PKG_BIN'
-launchers_write
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
