@@ -9,9 +9,9 @@ set -o errexit
 # Bastion
 ###
 
-script_version=20230918.1
+script_version=20240408.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.26'
+PLAYIT_COMPATIBILITY_LEVEL='2.28'
 
 GAME_ID='bastion'
 GAME_NAME='Bastion'
@@ -68,29 +68,34 @@ SDL2.dll'
 ## System-provided libmojoshader.so can not be used, as it triggers the following error:
 ## System.NullReferenceException: Object reference not set to an instance of an object
 ## cf. https://forge.dotslashplay.it/play.it/games/-/issues/653
-CONTENT_LIBS_LIBS32_PATH_GOG="${CONTENT_PATH_DEFAULT_GOG}/lib"
-CONTENT_LIBS_LIBS32_PATH_HUMBLE="${CONTENT_PATH_DEFAULT_HUMBLE}/lib"
-CONTENT_LIBS_LIBS32_FILES='
+CONTENT_LIBS_FILES='
 libfmodex.so
 libmojoshader.so'
 CONTENT_LIBS_LIBS64_PATH_GOG="${CONTENT_PATH_DEFAULT_GOG}/lib64"
 CONTENT_LIBS_LIBS64_PATH_HUMBLE="${CONTENT_PATH_DEFAULT_HUMBLE}/lib64"
-CONTENT_LIBS_LIBS64_FILES='
-libfmodex.so
-libmojoshader.so'
+CONTENT_LIBS_LIBS64_FILES="$CONTENT_LIBS_FILES"
+CONTENT_LIBS_LIBS32_PATH_GOG="${CONTENT_PATH_DEFAULT_GOG}/lib"
+CONTENT_LIBS_LIBS32_PATH_HUMBLE="${CONTENT_PATH_DEFAULT_HUMBLE}/lib"
+CONTENT_LIBS_LIBS32_FILES="$CONTENT_LIBS_FILES"
 ## libSteamWrapper.so is required to prevent a crash of the Humble Bundle build,
 ## libsteam_api.so is required by libSteamWrapper.so.
-CONTENT_LIBS_LIBS32_FILES_HUMBLE="$CONTENT_LIBS_LIBS32_FILES
+CONTENT_LIBS0_FILES='
 libSteamWrapper.so
-libsteam_api.so"
-CONTENT_LIBS_LIBS64_FILES_HUMBLE="$CONTENT_LIBS_LIBS64_FILES
-libSteamWrapper.so
-libsteam_api.so"
+libsteam_api.so'
+CONTENT_LIBS0_LIBS64_PATH_GOG="${CONTENT_PATH_DEFAULT_GOG}/lib64"
+CONTENT_LIBS0_LIBS64_PATH_HUMBLE="${CONTENT_PATH_DEFAULT_HUMBLE}/lib64"
+CONTENT_LIBS0_LIBS64_FILES_HUMBLE="$CONTENT_LIBS0_FILES"
+CONTENT_LIBS0_LIBS32_PATH_GOG="${CONTENT_PATH_DEFAULT_GOG}/lib"
+CONTENT_LIBS0_LIBS32_PATH_HUMBLE="${CONTENT_PATH_DEFAULT_HUMBLE}/lib"
+CONTENT_LIBS0_LIBS32_FILES_HUMBLE="$CONTENT_LIBS0_FILES"
 
 APP_MAIN_EXE='Bastion.exe'
 APP_MAIN_ICON='Bastion.bmp'
 
-PACKAGES_LIST='PKG_MAIN PKG_LIBS32 PKG_LIBS64'
+PACKAGES_LIST='
+PKG_MAIN
+PKG_LIBS32
+PKG_LIBS64'
 
 PKG_MAIN_DEPENDENCIES_LIBRARIES='
 libGL.so.1
@@ -112,10 +117,10 @@ System.Xml.dll
 System.Xml.Linq.dll'
 
 PKG_LIBS_ID="${GAME_ID}-libs"
-PKG_LIBS32_ID="$PKG_LIBS_ID"
-PKG_LIBS32_ARCH='32'
 PKG_LIBS64_ID="$PKG_LIBS_ID"
 PKG_LIBS64_ARCH='64'
+PKG_LIBS32_ID="$PKG_LIBS_ID"
+PKG_LIBS32_ARCH='32'
 PKG_MAIN_DEPS="${PKG_MAIN_DEPS:-} $PKG_LIBS_ID"
 
 # Load common functions
@@ -147,26 +152,18 @@ fi
 
 archive_extraction_default
 
-# Include game icon
-
-PKG='PKG_MAIN'
-icons_inclusion
-
 # Include game data
 
+content_inclusion_icons 'PKG_MAIN'
 content_inclusion_default
 
 # Write launchers
 
-PKG='PKG_MAIN'
-launchers_write
+launchers_generation 'PKG_MAIN'
 
 # Build packages
 
 packages_generation
-
-# Print instructions
-
 print_instructions
 
 # Clean up
