@@ -7,9 +7,9 @@ set -o errexit
 # Dark Reign 2
 ###
 
-script_version=20231106.4
+script_version=20240408.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.28'
 
 GAME_ID='dark-reign-2'
 GAME_NAME='Dark Reign 2'
@@ -70,13 +70,15 @@ users'
 USER_PERSISTENT_FILES='
 settings.cfg'
 
+WINE_VIRTUAL_DESKTOP='auto'
 WINE_WINETRICKS_VERBS='win98'
 
 APP_MAIN_EXE='dr2.exe'
 APP_MAIN_EXE_0='launcher.exe'
 APP_MAIN_ICON='dr2.exe'
 ## On first launch, register the game CD-key.
-APP_MAIN_PRERUN='# On first launch, register the game CD-key
+APP_MAIN_PRERUN="${APP_MAIN_PRERUN:-}"'
+# On first launch, register the game CD-key
 if [ ! -e .cdkey-registered ]; then
 	cdkey=$(cat cdkey)
 	$(wine_command) reg add "HKLM\\Software\\WON\\CDKeys" /v "DarkReign2" /t REG_BINARY /d "$cdkey" /f
@@ -98,8 +100,6 @@ PKG_BIN_DEPS="$PKG_DATA_ID"
 
 SCRIPT_DEPS="${SCRIPT_DEPS:-} base64 xxd"
 
-## FIXME: This game can get display issues on some resolutions, when run on Wayland without using a virtual desktop.
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -141,14 +141,12 @@ archive_extraction_default
 
 # Include game data
 
-set_current_package 'PKG_DATA'
-icons_inclusion
+content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
 # Write launchers
 
-set_current_package 'PKG_BIN'
-launchers_write
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
