@@ -8,9 +8,9 @@ set -o errexit
 # Deus Ex
 ###
 
-script_version=20231018.1
+script_version=20240408.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.28'
 
 GAME_ID='deus-ex'
 GAME_NAME='Deus Ex'
@@ -112,31 +112,22 @@ system/*.log'
 USER_PERSISTENT_DIRECTORIES='
 save'
 
+## TODO: Check if the virtual desktop prevents the game from messing with the desktop gamma value on X.org.
+WINE_VIRTUAL_DESKTOP='auto'
 ## Disable csmt, as it would cause performance issues with single CPU affinity.
 WINE_WINETRICKS_VERBS='csmt=off'
 
 APP_MAIN_EXE='system/deusex.exe'
-## Run the game binary from its parent directory
-APP_MAIN_PRERUN='# Run the game binary from its parent directory
+## Run the game binary from its parent directory.
+APP_MAIN_PRERUN="${APP_MAIN_PRERUN:-}"'
+# Run the game binary from its parent directory
 cd "$(dirname "$APP_EXE")"
 APP_EXE=$(basename "$APP_EXE")
 '
-## Set the CPU affinity to a single core, to work around a random crash on launch
-## cf. https://www.gamingonlinux.com/2020/02/the-sad-case-of-unreal-engine-1-on-mesa-and-linux-in-2020/page=2#r174041
-APP_MAIN_PRERUN="${APP_MAIN_PRERUN:-}"'
-# Set the CPU affinity to a single core, to work around a random crash on launch
-# cf. https://www.gamingonlinux.com/2020/02/the-sad-case-of-unreal-engine-1-on-mesa-and-linux-in-2020/page=2#r174041
-wine_command() {
-	printf "taskset --cpu-list 0 "
-    if [ -z "$PLAYIT_WINE_CMD" ]; then
-        command -v wine
-        return 0
-    fi
-    printf "%s" "$PLAYIT_WINE_CMD"
-}
-'
 
-PACKAGES_LIST='PKG_BIN PKG_DATA'
+PACKAGES_LIST='
+PKG_BIN
+PKG_DATA'
 
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
@@ -148,9 +139,6 @@ PKG_BIN_DEPS="$PKG_DATA_ID"
 
 SCRIPT_DEPS="${SCRIPT_DEPS:-} sed unix2dos"
 
-## FIXME: This game can mess up desktop gamma values.
-## FIXME: This game should be run in a WINE virtual desktop.
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -176,13 +164,24 @@ if [ -z "$PLAYIT_LIB2" ]; then
 fi
 . "$PLAYIT_LIB2"
 
+# Set the CPU affinity to a single core, to work around a random crash on launch.
+# cf. https://www.gamingonlinux.com/2020/02/the-sad-case-of-unreal-engine-1-on-mesa-and-linux-in-2020/page=2#r174041
+
+game_exec_line() {
+	cat <<- 'EOF'
+	# Set the CPU affinity to a single core, to work around a random crash on launch
+	# cf. https://www.gamingonlinux.com/2020/02/the-sad-case-of-unreal-engine-1-on-mesa-and-linux-in-2020/page=2#r174041
+	taskset --cpu-list 0 $(wine_command) "$APP_EXE" "$@"
+	EOF
+}
+
 # Extract game data
 
 archive_extraction_default
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	## Set OpenGL as default rendering engine
+	## Set OpenGL as default rendering engine.
 	ini_file='system/deusex.ini'
 	ini_field='GameRenderDevice'
 	ini_value='OpenGLDrv.OpenGLRenderDevice'
@@ -197,14 +196,12 @@ archive_extraction_default
 
 # Include game data
 
-set_current_package 'PKG_DATA'
-icons_inclusion
+content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
 # Write launchers
 
-set_current_package 'PKG_BIN'
-launchers_write
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
