@@ -7,9 +7,9 @@ set -o errexit
 # Frostpunk
 ###
 
-script_version=20230920.1
+script_version=20240412.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.26'
+PLAYIT_COMPATIBILITY_LEVEL='2.28'
 
 GAME_ID='frostpunk'
 GAME_NAME='Frostpunk'
@@ -144,11 +144,29 @@ gfxconfig.ini'
 APP_MAIN_EXE='frostpunk.exe'
 APP_MAIN_ICON='frostpunk.exe'
 ## Create some required empty files
-APP_MAIN_PRERUN='# Create some required empty files
+APP_MAIN_PRERUN="${APP_MAIN_PRERUN:-}"'
+# Create some required empty files
 touch custom_localizations.dat voices.dat
 '
+## The game crashes on launch when SDL_VIDEODRIVER is set to "wayland".
+APP_MAIN_PRERUN="${APP_MAIN_PRERUN:-}"'
+# The game crashes on launch when SDL_VIDEODRIVER is set to "wayland".
+if [ "${SDL_VIDEODRIVER:-}" = "wayland" ]; then
+	unset SDL_VIDEODRIVER
+fi
+'
+## The game crashes on launch when SDL_AUDIODRIVER is set to "alsa".
+APP_MAIN_PRERUN="${APP_MAIN_PRERUN:-}"'
+# The game crashes on launch when SDL_AUDIODRIVER is set to "alsa".
+if [ "${SDL_AUDIODRIVER:-}" = "alsa" ]; then
+	unset SDL_AUDIODRIVER
+fi
+'
 
-PACKAGES_LIST='PKG_BIN PKG_TEXTURES PKG_DATA'
+PACKAGES_LIST='
+PKG_BIN
+PKG_TEXTURES
+PKG_DATA'
 
 PKG_TEXTURES_ID="${GAME_ID}-textures"
 PKG_TEXTURES_DESCRIPTION='textures'
@@ -191,7 +209,8 @@ archive_extraction_default
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	# Delete files that should not be included
+	## Delete files that should not be included.
+	## TODO: This could be avoided by more targeted files inclusion lists.
 	rm --force --recursive \
 		'__redist' \
 		'app' \
@@ -199,26 +218,46 @@ archive_extraction_default
 		'tmp'
 )
 
-# Include game icons
-
-PKG='PKG_DATA'
-icons_inclusion
-
 # Include game data
 
+content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
 # Write launchers
 
-PKG='PKG_BIN'
-launchers_write
+## Force the use of DXVK 2.3, to avoid a crash on launch with DXVK 2.3.1.
+## cf. https://github.com/doitsujin/dxvk/issues/3920
+## TODO: This override could probably be dropped after the next DXVK release (2.3.2 or 2.4.0).
+wine_launcher_renderer_dxvk() {
+	{
+		cat <<- 'EOF'
+		    ## Use DXVK for Direct3D 9/10/11 rendering
+		    if command -v winetricks >/dev/null 2>&1; then
+		        winetricks_wrapper dxvk2030
+		    else
+		        message="\\033[1;33mWarning:\\033[0m\\n"
+		        message="${message}DXVK patches could not be installed in the WINE prefix.\\n"
+		        message="${message}The game might run with display or performance issues.\\n"
+		        printf "\\n${message}\\n"
+		    fi
+
+		    ## Wait a bit to ensure there is no lingering wine process
+		    sleep 1s
+
+		EOF
+	} | sed --regexp-extended 's/( ){4}/\t/g'
+
+	# Automatically add required dependencies to the current package
+	local package
+	package=$(current_package)
+	dependencies_add_native_libraries "$package" 'libvulkan.so.1'
+	dependencies_add_command "$package" 'winetricks'
+}
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
 packages_generation
-
-# Print instructions
-
 print_instructions
 
 # Clean up
