@@ -7,9 +7,9 @@ set -o errexit
 # Heroes of Might and Magic 4
 ###
 
-script_version=20231018.1
+script_version=20240408.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.28'
 
 GAME_ID='heroes-of-might-and-magic-4'
 GAME_NAME='Heroes of Might and Magic Ⅳ'
@@ -80,25 +80,34 @@ CONTENT_PATH_DEFAULT='.'
 CONTENT_PATH_DEFAULT_EN_0='app'
 CONTENT_PATH_DEFAULT_FR_0='app'
 CONTENT_GAME_BIN_FILES='
-binkw32.dll
-drvmgt.dll
-mss32.dll
 mp3dec.asi
-data/*.dll
-*.exe'
+binkw32.dll
+mss32.dll
+data/binkw32.dll
+data/mss32.dll
+campaign_editor.exe
+dxcfg.exe
+heroes4.exe'
 CONTENT_GAME_DATA_FILES='
 data
 maps'
 CONTENT_DOC_DATA_FILES='
-*.chm
-*.pdf
-*.txt'
+campaign_editor_help.chm
+h4gsmanual.pdf
+h4manual.pdf
+h4qref.pdf
+h4towntrees.pdf
+h4wwmanual.pdf
+multiplayer.txt
+readme.txt'
 
 USER_PERSISTENT_DIRECTORIES='
 games'
 USER_PERSISTENT_FILES='
 data/high_scores.dat'
 
+WINE_VIRTUAL_DESKTOP='1280x1024'
+
 APP_MAIN_EXE='heroes4.exe'
 APP_MAIN_ICON='heroes4.exe'
 
@@ -107,7 +116,9 @@ APP_EDITOR_EXE='campaign_editor.exe'
 APP_EDITOR_ICON='campaign_editor.exe'
 APP_EDITOR_NAME="$GAME_NAME - campaign editor"
 
-PACKAGES_LIST='PKG_BIN PKG_DATA'
+PACKAGES_LIST='
+PKG_BIN
+PKG_DATA'
 
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_ID_EN="${PKG_DATA_ID}-en"
@@ -129,8 +140,6 @@ PKG_BIN_DESCRIPTION_FR='French version'
 PKG_BIN_DEPS_EN="$PKG_DATA_ID_EN"
 PKG_BIN_DEPS_FR="$PKG_DATA_ID_FR"
 
-## FIXME: This game should be run in a WINE virtual desktop,
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -162,14 +171,12 @@ archive_extraction_default
 
 # Include game data
 
-set_current_package 'PKG_DATA'
-icons_inclusion
+content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
 # Write launchers
 
-set_current_package 'PKG_BIN'
-launchers_write
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
