@@ -12,9 +12,9 @@ set -o errexit
 # - Planescape: Torment Enhanced Edition
 ###
 
-script_version=20231016.1
+script_version=20240528.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.29'
 
 GAME_ID_BG1='baldurs-gate-1-enhanced-edition'
 GAME_NAME_BG1='Baldurʼs Gate Enhanced Edition'
@@ -43,6 +43,20 @@ ARCHIVE_BASE_BG1_0_MD5='a87444f36602b5059e3c885ec2ff50e1'
 ARCHIVE_BASE_BG1_0_SIZE='3300000'
 ARCHIVE_BASE_BG1_0_VERSION='2.6.5.0-gog46477'
 
+### Option icons pack
+
+ARCHIVE_OPTIONAL_ICONS_NAME_BG1='baldurs-gate-1-enhanced-edition_icons.tar.gz'
+ARCHIVE_OPTIONAL_ICONS_MD5_BG1='58401cf80bc9f1a9e9a0896f5d74b02a'
+ARCHIVE_OPTIONAL_ICONS_URL_BG1='https://downloads.dotslashplay.it/resources/baldurs-gate-1-enhanced-edition/'
+CONTENT_ICONS_PATH_BG1='.'
+CONTENT_ICONS_FILES_BG1='
+16x16
+24x42
+32x32
+48x48
+64x64
+256x256'
+
 ## Baldur's Gate 2 Enhanced Edition
 
 ARCHIVE_BASE_BG2_1_NAME='baldur_s_gate_ii_enhanced_edition_2_6_6_0_47292.sh'
@@ -56,6 +70,20 @@ ARCHIVE_BASE_BG2_0_MD5='aa62efd4b1c69f074a784e637234e7c4'
 ARCHIVE_BASE_BG2_0_SIZE='3800000'
 ARCHIVE_BASE_BG2_0_VERSION='2.6.5.0-gog46477'
 
+### Optional icons pack
+
+ARCHIVE_OPTIONAL_ICONS_NAME_BG2='baldurs-gate-2-enhanced-edition_icons.tar.gz'
+ARCHIVE_OPTIONAL_ICONS_MD5_BG2='36055600f9461793995a318e74b133e8'
+ARCHIVE_OPTIONAL_ICONS_URL_BG2='https://downloads.dotslashplay.it/games/baldurs-gate-2-enhanced-edition/'
+CONTENT_ICONS_PATH_BG2='.'
+CONTENT_ICONS_FILES_BG2='
+16x16
+32x32
+48x48
+64x64
+128x128
+256x256'
+
 ## Icewind Dale 1 Enhanced Edition
 
 ARCHIVE_BASE_IWD1_1_NAME='icewind_dale_enhanced_edition_2_6_6_0_47290.sh'
@@ -69,6 +97,20 @@ ARCHIVE_BASE_IWD1_0_MD5='7fa481705b5d5b7f5d714a6a19c856e0'
 ARCHIVE_BASE_IWD1_0_SIZE='3000000'
 ARCHIVE_BASE_IWD1_0_VERSION='2.6.5.0-gog46474'
 
+### Optional icons pack
+
+ARCHIVE_OPTIONAL_ICONS_NAME_IWD1='icewind-dale-1-enhanced-edition_icons.tar.gz'
+ARCHIVE_OPTIONAL_ICONS_MD5_IWD1='2e7db406aca79f9182c4efa93df80bf4'
+ARCHIVE_OPTIONAL_ICONS_URL_IWD1='https://downloads.dotslashplay.it/resources/icewind-dale-1-enhanced-edition/'
+CONTENT_ICONS_PATH_IWD1='.'
+CONTENT_ICONS_FILES_IWD1='
+16x16
+32x32
+48x48
+64x64
+128x128
+256x256'
+
 ## Planescape: Torment
 
 ARCHIVE_BASE_PST_1_NAME='planescape_torment_enhanced_edition_3_1_4_26532.sh'
@@ -82,6 +124,21 @@ ARCHIVE_BASE_PST_0_MD5='649c1bf9d7ccd81553c574ff1bec2cef'
 ARCHIVE_BASE_PST_0_SIZE='1800000'
 ARCHIVE_BASE_PST_0_VERSION='3.1.3-gog2.1.0.3'
 
+### Optional icons pack
+
+ARCHIVE_OPTIONAL_ICONS_NAME_PST='planescape-torment-enhanced-edition_icons.tar.gz'
+ARCHIVE_OPTIONAL_ICONS_MD5_PST='ed1c9961e2ecfa401af825d75723fe9c'
+ARCHIVE_OPTIONAL_ICONS_URL_PST='https://downloads.dotslashplay.it/games/planescape-torment-enhanced-edition/'
+CONTENT_ICONS_PATH_PST='.'
+CONTENT_ICONS_FILES_PST='
+16x16
+32x32
+48x48
+64x64
+96x96
+128x128
+256x256'
+
 
 CONTENT_PATH_DEFAULT='data/noarch/game'
 CONTENT_GAME_BIN_FILES_BG1='
@@ -92,6 +149,8 @@ CONTENT_GAME_BIN_FILES_IWD1='
 IcewindDale'
 CONTENT_GAME_BIN_FILES_PST='
 Torment64'
+CONTENT_GAME_L10N_EN_FILES='
+lang/en_US'
 CONTENT_GAME_L10N_FR_FILES='
 lang/fr_FR'
 CONTENT_GAME_DATA_FILES='
@@ -101,8 +160,7 @@ Manuals
 movies
 music
 scripts
-data
-lang/en_US'
+data'
 CONTENT_DOC_DATA_PATH="${CONTENT_PATH_DEFAULT}/../docs"
 CONTENT_DOC_DATA_FILES='*'
 
@@ -110,6 +168,7 @@ APP_MAIN_EXE_BG1='BaldursGate'
 APP_MAIN_EXE_BG2='BaldursGateII'
 APP_MAIN_EXE_IWD1='IcewindDale'
 APP_MAIN_EXE_PST='Torment64'
+APP_MAIN_ICON='../support/icon.png'
 ## The game segfaults on launch when SDL_VIDEODRIVER is set to "wayland".
 ## Forcing the use of system-provided SDL with SDL_DYNAMIC_API does not help.
 APP_MAIN_PRERUN='# The game segfaults on launch when SDL_VIDEODRIVER is set to "wayland".
@@ -120,8 +179,13 @@ fi
 
 # Packages
 
-PACKAGES_LIST='PKG_BIN PKG_L10N_FR PKG_DATA'
+PACKAGES_LIST='
+PKG_BIN
+PKG_L10N_EN
+PKG_L10N_FR
+PKG_DATA'
 
+PKG_L10N_EN_DESCRIPTION='English localization'
 PKG_L10N_FR_DESCRIPTION='French localization'
 
 PKG_DATA_DESCRIPTION='data'
@@ -143,43 +207,59 @@ libX11.so.6'
 
 ## Baldur's Gate 1 Enhanced Edition
 
-PKG_L10N_FR_ID_BG1="${GAME_ID_BG1}-l10n-fr"
-PKG_L10N_FR_DESCRIPTION_BG1="$PKG_L10N_FR_DESCRIPTION"
-PKG_L10N_FR_DEPS_BG1="$GAME_ID_BG1"
+PKG_L10N_ID_BG1="${GAME_ID_BG1}-l10n"
+PKG_L10N_EN_ID_BG1="${PKG_L10N_ID_BG1}-en"
+PKG_L10N_FR_ID_BG1="${PKG_L10N_ID_BG1}-fr"
+PKG_L10N_PROVIDES_BG1="
+$PKG_L10N_ID_BG1"
+PKG_L10N_EN_PROVIDES_BG1="$PKG_L10N_PROVIDES_BG1"
+PKG_L10N_FR_PROVIDES_BG1="$PKG_L10N_PROVIDES_BG1"
 
 PKG_DATA_ID_BG1="${GAME_ID_BG1}-data"
 
-PKG_BIN_DEPS_BG1="$PKG_DATA_ID_BG1"
+PKG_BIN_DEPS_BG1="$PKG_L10N_ID_BG1 $PKG_DATA_ID_BG1"
 
 ## Baldur's Gate 2 Enhanced Edition
 
-PKG_L10N_FR_ID_BG2="${GAME_ID_BG2}-l10n-fr"
-PKG_L10N_FR_DESCRIPTION_BG2="$PKG_L10N_FR_DESCRIPTION"
-PKG_L10N_FR_DEPS_BG2="$GAME_ID_BG2"
+PKG_L10N_ID_BG2="${GAME_ID_BG2}-l10n"
+PKG_L10N_EN_ID_BG2="${PKG_L10N_ID_BG2}-en"
+PKG_L10N_FR_ID_BG2="${PKG_L10N_ID_BG2}-fr"
+PKG_L10N_PROVIDES_BG2="
+$PKG_L10N_ID_BG2"
+PKG_L10N_EN_PROVIDES_BG2="$PKG_L10N_PROVIDES_BG2"
+PKG_L10N_FR_PROVIDES_BG2="$PKG_L10N_PROVIDES_BG2"
 
 PKG_DATA_ID_BG2="${GAME_ID_BG2}-data"
 
-PKG_BIN_DEPS_BG2="$PKG_DATA_ID_BG2"
+PKG_BIN_DEPS_BG2="$PKG_L10N_ID_BG2 $PKG_DATA_ID_BG2"
 
 ## Icewind Dale 1 Enhanced Edition
 
-PKG_L10N_FR_ID_IWD1="${GAME_ID_IWD1}-l10n-fr"
-PKG_L10N_FR_DESCRIPTION_IWD1="$PKG_L10N_FR_DESCRIPTION"
-PKG_L10N_FR_DEPS_IWD1="$GAME_ID_IWD1"
+PKG_L10N_ID_IWD1="${GAME_ID_IWD1}-l10n"
+PKG_L10N_EN_ID_IWD1="${PKG_L10N_ID_IWD1}-en"
+PKG_L10N_FR_ID_IWD1="${PKG_L10N_ID_IWD1}-fr"
+PKG_L10N_PROVIDES_IWD1="
+$PKG_L10N_ID_IWD1"
+PKG_L10N_EN_PROVIDES_IWD1="$PKG_L10N_PROVIDES_IWD1"
+PKG_L10N_FR_PROVIDES_IWD1="$PKG_L10N_PROVIDES_IWD1"
 
 PKG_DATA_ID_IWD1="${GAME_ID_IWD1}-data"
 
-PKG_BIN_DEPS_IWD1="$PKG_DATA_ID_IWD1"
+PKG_BIN_DEPS_IWD1="$PKG_L10N_ID_IWD1 $PKG_DATA_ID_IWD1"
 
 ## Planescape: Torment Enhanced Edition
 
-PKG_L10N_FR_ID_PST="${GAME_ID_PST}-l10n-fr"
-PKG_L10N_FR_DESCRIPTION_PST="$PKG_L10N_FR_DESCRIPTION"
-PKG_L10N_FR_DEPS_PST="$GAME_ID_PST"
+PKG_L10N_ID_PST="${GAME_ID_PST}-l10n"
+PKG_L10N_EN_ID_PST="${PKG_L10N_ID_PST}-en"
+PKG_L10N_FR_ID_PST="${PKG_L10N_ID_PST}-fr"
+PKG_L10N_PROVIDES_PST="
+$PKG_L10N_ID_PST"
+PKG_L10N_EN_PROVIDES_PST="$PKG_L10N_PROVIDES_PST"
+PKG_L10N_FR_PROVIDES_PST="$PKG_L10N_PROVIDES_PST"
 
 PKG_DATA_ID_PST="${GAME_ID_PST}-data"
 
-PKG_BIN_DEPS_PST="$PKG_DATA_ID_PST"
+PKG_BIN_DEPS_PST="$PKG_L10N_ID_PST $PKG_DATA_ID_PST"
 
 # Load common functions
 
@@ -206,101 +286,18 @@ if [ -z "$PLAYIT_LIB2" ]; then
 fi
 . "$PLAYIT_LIB2"
 
-# Check for the presence of optional extra archives
-
-case "$(current_archive)" in
-	('ARCHIVE_BASE_BG1_'*)
-		ARCHIVE_OPTIONAL_ICONS_NAME='baldurs-gate-1-enhanced-edition_icons.tar.gz'
-		ARCHIVE_OPTIONAL_ICONS_MD5='58401cf80bc9f1a9e9a0896f5d74b02a'
-		ARCHIVE_OPTIONAL_ICONS_URL='https://downloads.dotslashplay.it/resources/baldurs-gate-1-enhanced-edition/'
-	;;
-	('ARCHIVE_BASE_BG2_'*)
-		ARCHIVE_OPTIONAL_ICONS_NAME='baldurs-gate-2-enhanced-edition_icons.tar.gz'
-		ARCHIVE_OPTIONAL_ICONS_MD5='36055600f9461793995a318e74b133e8'
-		ARCHIVE_OPTIONAL_ICONS_URL='https://downloads.dotslashplay.it/games/baldurs-gate-2-enhanced-edition/'
-	;;
-	('ARCHIVE_BASE_IWD1_'*)
-		ARCHIVE_OPTIONAL_ICONS_NAME='icewind-dale-1-enhanced-edition_icons.tar.gz'
-		ARCHIVE_OPTIONAL_ICONS_MD5='2e7db406aca79f9182c4efa93df80bf4'
-		ARCHIVE_OPTIONAL_ICONS_URL='https://downloads.dotslashplay.it/resources/icewind-dale-1-enhanced-edition/'
-	;;
-	('ARCHIVE_BASE_PST_'*)
-		ARCHIVE_OPTIONAL_ICONS_NAME='planescape-torment-enhanced-edition_icons.tar.gz'
-		ARCHIVE_OPTIONAL_ICONS_MD5='ed1c9961e2ecfa401af825d75723fe9c'
-		ARCHIVE_OPTIONAL_ICONS_URL='https://downloads.dotslashplay.it/games/planescape-torment-enhanced-edition/'
-	;;
-esac
-archive_initialize_optional \
-	'ARCHIVE_ICONS' \
-	'ARCHIVE_OPTIONAL_ICONS'
-
 # Extract game data
 
 archive_extraction_default
-if archive_is_available 'ARCHIVE_ICONS'; then
-	archive_extraction 'ARCHIVE_ICONS'
-fi
 
 # Include game data
 
-## Use the original game icons from the optional archive,
-## or fall back on the GOG-specific icon shipped in the game installer.
-if archive_is_available 'ARCHIVE_ICONS'; then
-	case "$(current_archive)" in
-		('ARCHIVE_BASE_BG1_'*)
-			CONTENT_ICONS_DATA_PATH='.'
-			CONTENT_ICONS_DATA_FILES='
-			16x16
-			24x42
-			32x32
-			48x48
-			64x64
-			256x256'
-		;;
-		('ARCHIVE_BASE_BG2_'*)
-			CONTENT_ICONS_DATA_PATH='.'
-			CONTENT_ICONS_DATA_FILES='
-			16x16
-			32x32
-			48x48
-			64x64
-			128x128
-			256x256'
-		;;
-		('ARCHIVE_BASE_IWD1_'*)
-			CONTENT_ICONS_DATA_PATH='.'
-			CONTENT_ICONS_DATA_FILES='
-			16x16
-			32x32
-			48x48
-			64x64
-			128x128
-			256x256'
-		;;
-		('ARCHIVE_BASE_PST_'*)
-			CONTENT_ICONS_DATA_PATH='.'
-			CONTENT_ICONS_DATA_FILES='
-			16x16
-			32x32
-			48x48
-			64x64
-			96x96
-			128x128
-			256x256'
-		;;
-	esac
-	content_inclusion 'ICONS_DATA' 'PKG_DATA' "$(path_icons)"
-else
-	APP_MAIN_ICON='../support/icon.png'
-	set_current_package 'PKG_DATA'
-	icons_inclusion
-fi
+content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
 # Write launchers
 
-set_current_package 'PKG_BIN'
-launchers_write
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
@@ -319,7 +316,7 @@ case "${LANG%_*}" in
 esac
 printf '\n'
 printf "$lang_string" "$lang_en"
-print_instructions 'PKG_BIN' 'PKG_DATA'
+print_instructions 'PKG_BIN' 'PKG_DATA' 'PKG_L10N_EN'
 printf "$lang_string" "$lang_fr"
 print_instructions 'PKG_BIN' 'PKG_DATA' 'PKG_L10N_FR'
 
