@@ -12,9 +12,9 @@ set -o errexit
 # - Planescape: Torment
 ###
 
-script_version=20230916.1
+script_version=20240409.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.26'
+PLAYIT_COMPATIBILITY_LEVEL='2.28'
 
 GAME_ID_BG1='baldurs-gate-1'
 GAME_NAME_BG1='Baldurʼs Gate'
@@ -158,10 +158,6 @@ CONTENT_PATH_DEFAULT_IWD2='app'
 CONTENT_PATH_DEFAULT_PST_EN='data/noarch/prefix/drive_c/GOG Games/Planescape Torment'
 CONTENT_PATH_DEFAULT_PST_RU='data/noarch/prefix/drive_c/GOG Games/Planescape Torment (Russian)'
 CONTENT_PATH_DEFAULT_PST_FR='data/noarch/prefix/drive_c/GOG Games/Planescape Torment (French)'
-CONTENT_DOC_L10N_FILES='
-*.htm
-*.pdf
-*.txt'
 CONTENT_GAME_BIN_FILES='
 luaauto.cfg
 lasnil32.dll
@@ -176,7 +172,7 @@ keymap.ini
 layout.ini
 quests.ini
 torment.ini
-script?compiler
+script compiler
 *.exe'
 CONTENT_GAME_L10N_FILES='
 cachemos.bif
@@ -218,6 +214,10 @@ music
 scripts
 *.bif
 *.mpi'
+CONTENT_DOC_L10N_FILES='
+*.htm
+*.pdf
+*.txt'
 CONTENT_DOC0_L10N_PATH_BG1_EN='data/noarch/docs/english'
 CONTENT_DOC0_L10N_PATH_BG1_FR='data/noarch/docs/french'
 CONTENT_DOC0_L10N_PATH_BG1_PL='data/noarch/docs/polish'
@@ -233,9 +233,13 @@ CONTENT_DOC0_L10N_PATH_PST_RU='data/noarch/docs/russian'
 CONTENT_DOC0_L10N_PATH_PST_EN_0='data/noarch/docs'
 CONTENT_DOC0_L10N_PATH_PST_FR_0='data/noarch/docs'
 CONTENT_DOC0_L10N_PATH_PST_RU_0='data/noarch/docs'
-CONTENT_DOC0_L10N_FILES_BG1='*'
-CONTENT_DOC0_L10N_FILES_BG2='*'
-CONTENT_DOC0_L10N_FILES_PST='*'
+## FIXME: An explicit files list should be given.
+CONTENT_DOC0_L10N_FILES_BG1='
+*'
+CONTENT_DOC0_L10N_FILES_BG2='
+*'
+CONTENT_DOC0_L10N_FILES_PST='
+*'
 
 # Applications
 
@@ -246,7 +250,8 @@ characters
 mpsave
 save'
 
-## Disable the multi-threaded command stream feature, as it has a very severe impact on performances
+WINE_VIRTUAL_DESKTOP='auto'
+## Disable the multi-threaded command stream feature, as it has a very severe impact on performances.
 WINE_WINETRICKS_VERBS='csmt=off'
 
 APPLICATIONS_LIST='APP_MAIN APP_CONFIG'
@@ -268,8 +273,10 @@ APP_CONFIG_ICON_BG1='config.exe'
 
 APP_MAIN_EXE_BG2='bgmain.exe'
 APP_MAIN_ICON_BG2='baldur.exe'
-## Merge "data" and "data/data"
-APP_MAIN_PRERUN_BG2='# Merge "data" and "data/data"
+## Merge "data" and "data/data".
+## TODO: The symbolic link could probably be shipped in the package instead.
+APP_MAIN_PRERUN_BG2='
+# Merge "data" and "data/data"
 ln --symbolic --force --no-target-directory . "data/data"
 '
 
@@ -307,7 +314,10 @@ APP_MAIN_ICON_PST='torment.exe'
 
 ## Common
 
-PACKAGES_LIST='PKG_BIN PKG_L10N PKG_DATA'
+PACKAGES_LIST='
+PKG_BIN
+PKG_L10N
+PKG_DATA'
 
 PKG_L10N_DESCRIPTION_EN='English localization'
 PKG_L10N_DESCRIPTION_FR='French localization'
@@ -418,10 +428,8 @@ archive_extraction_default
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	# Get the current archive
-	current_archive=$(context_archive)
-
-	# Delete unwanted files
+	## Delete unwanted files.
+	## TODO: Check if the explicit removal is still required.
 	rm --force --recursive \
 		'__support' \
 		'gameuxinstallhelper.dll' \
@@ -430,29 +438,29 @@ archive_extraction_default
 		'ddrawfix' \
 		'setup-ddrawfix.exe'
 
-	# mojosetup installers
-	# - Convert all file names to lowercase
-	if [ "$(archive_get_type "$current_archive")" = 'mojosetup' ]; then
+	## Mojosetup installers
+	## - Convert all file names to lowercase
+	if [ "$(archive_type "$(current_archive)")" = 'mojosetup' ]; then
 		tolower .
 	fi
 
-	# Baldur's Gate 2
-	# - Delete broken symbolic links
-	# - Merge "data" and "data/data"
-	case "$current_archive" in
+	## Baldur's Gate 2
+	## - Delete broken symbolic links
+	## - Merge "data" and "data/data"
+	case "$(current_archive)" in
 		('ARCHIVE_BASE_BG2_'*)
 			rm --force --recursive \
 				'mpsave' \
 				'temp'
 			if [ -e 'data/data' ]; then
-				cp --link --no-clobber --recursive 'data/data/'* 'data/'
+				cp --link --recursive --update=none 'data/data/'* 'data/'
 				rm --force --recursive 'data/data'
 			fi
 		;;
 	esac
 
-	# Generate a minimal configuration file
-	case "$current_archive" in
+	## Generate a minimal configuration file/
+	case "$(current_archive)" in
 		('ARCHIVE_BASE_BG1_'*)
 			config_file='baldur.ini'
 		;;
@@ -470,7 +478,7 @@ archive_extraction_default
 		;;
 	esac
 	game_path="C:\\$(game_id)"
-	case "$current_archive" in
+	case "$(current_archive)" in
 		('ARCHIVE_BASE_BG1_'*)
 			cat > "$config_file" <<- EOF
 			[Alias]
@@ -532,26 +540,18 @@ archive_extraction_default
 	EOF
 )
 
-# Include game icons
-
-PKG='PKG_DATA'
-icons_inclusion
-
 # Include game data
 
+content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
 # Write launchers
 
-PKG='PKG_BIN'
-launchers_write
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
 packages_generation
-
-# Print instructions
-
 print_instructions
 
 # Clean up
