@@ -8,9 +8,9 @@ set -o errexit
 # Pillars of Eternity 1
 ###
 
-script_version=20230922.1
+script_version=20240411.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.26'
+PLAYIT_COMPATIBILITY_LEVEL='2.28'
 
 GAME_ID='pillars-of-eternity-1'
 GAME_NAME='Pillars of Eternity'
@@ -44,7 +44,10 @@ CONTENT_PATH_DEFAULT='data/noarch/game'
 CONTENT_GAME_DATA_AREAS_FILES="
 ${UNITY3D_NAME}_Data/assetbundles/st_ar_*"
 
-PACKAGES_LIST='PKG_BIN PKG_DATA_AREAS PKG_DATA'
+PACKAGES_LIST='
+PKG_BIN
+PKG_DATA_AREAS
+PKG_DATA'
 
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
@@ -101,26 +104,18 @@ fi
 
 archive_extraction_default
 
-# Include game icons
-
-PKG='PKG_DATA'
-icons_inclusion
-
 # Include game data
 
+content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
 # Write launchers
 
-PKG='PKG_BIN'
-launchers_write
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
 packages_generation
-
-# Print instructions
-
 print_instructions
 
 # Clean up
