@@ -8,9 +8,9 @@ set -o errexit
 # Raji: An Ancient Epic
 ###
 
-script_version=20240109.1
+script_version=20240504.2
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.28'
 
 GAME_ID='raji-an-ancient-epic'
 GAME_NAME='Raji: An Ancient Epic'
@@ -51,6 +51,15 @@ ARCHIVE_BASE_DEMO_0_SIZE='3100000'
 ARCHIVE_BASE_DEMO_0_VERSION='11-itch.2020.10.21'
 ARCHIVE_BASE_DEMO_0_URL='https://rajithegame.itch.io/raji-an-ancient-epic'
 
+## Optional icons pack
+
+ARCHIVE_OPTIONAL_ICONS_NAME='raji-an-ancient-epic_icons.tar.gz'
+ARCHIVE_OPTIONAL_ICONS_MD5='befa06adad5d44a2946cc19f54b0a267'
+ARCHIVE_OPTIONAL_ICONS_URL='http://downloads.dotslashplay.it/games/raji-an-ancient-epic/'
+CONTENT_ICONS_PATH='.'
+CONTENT_ICONS_FILES='
+256x256'
+
 
 UNREALENGINE4_NAME='raji'
 
@@ -62,7 +71,9 @@ APP_MAIN_EXE="${UNREALENGINE4_NAME}.exe"
 ## We force Direct3D 11 instead as it is better supported by current WINE builds.
 APP_MAIN_OPTIONS='-d3d11'
 
-PACKAGES_LIST='PKG_BIN PKG_DATA'
+PACKAGES_LIST='
+PKG_BIN
+PKG_DATA'
 
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_ID_DEMO="${GAME_ID_DEMO}-data"
@@ -72,8 +83,6 @@ PKG_BIN_ARCH='64'
 PKG_BIN_DEPS="$PKG_DATA_ID"
 PKG_BIN_DEPS_DEMO="$PKG_DATA_ID_DEMO"
 
-## FIXME: This game can get display issues on some resolutions, when run on Wayland without using a virtual desktop.
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -99,57 +108,34 @@ if [ -z "$PLAYIT_LIB2" ]; then
 fi
 . "$PLAYIT_LIB2"
 
-# Check for the presence of optional extra archives
-
-ARCHIVE_OPTIONAL_ICONS_NAME='raji-an-ancient-epic_icons.tar.gz'
-ARCHIVE_OPTIONAL_ICONS_MD5='befa06adad5d44a2946cc19f54b0a267'
-ARCHIVE_OPTIONAL_ICONS_URL='http://downloads.dotslashplay.it/games/raji-an-ancient-epic/'
-archive_initialize_optional \
-	'ARCHIVE_ICONS' \
-	'ARCHIVE_OPTIONAL_ICONS'
-
 # Extract game data
 
 archive_extraction_default
-if archive_is_available 'ARCHIVE_ICONS'; then
-	archive_extraction 'ARCHIVE_ICONS'
-fi
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
 	## Convert all file paths to lowercase.
 	tolower .
 )
-(
-	cd "${PLAYIT_WORKDIR}/gamedata"
-
-	## Convert icon file name for the game demo.
-	case "$(current_archive)" in
-		('ARCHIVE_BASE_DEMO_'*)
-			mv \
-				"256x256/apps/${GAME_ID}.png" \
-				"256x256/apps/$(game_id).png"
-		;;
-	esac
-)
 
 # Include game data
 
-if archive_is_available 'ARCHIVE_ICONS'; then
-	CONTENT_ICONS_DATA_PATH='.'
-	CONTENT_ICONS_DATA_FILES='
-	256x256'
-	content_inclusion 'ICONS_DATA' 'PKG_DATA' "$(path_icons)"
-else
-	set_current_package 'PKG_DATA'
-	icons_inclusion
-fi
+content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
+## Convert icon file name for the game demo.
+case "$(current_archive)" in
+	('ARCHIVE_BASE_DEMO_'*)
+		icon_source="$(package_path 'PKG_DATA')$(path_icons)/256x256/apps/${GAME_ID}.png"
+		icon_destination="$(package_path 'PKG_DATA')$(path_icons)/256x256/apps/$(game_id).png"
+		if [ -e "$icon_source" ]; then
+			mv "$icon_source" "$icon_destination"
+		fi
+	;;
+esac
 
 # Write launchers
 
-set_current_package 'PKG_BIN'
-launchers_write
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
