@@ -7,9 +7,9 @@ set -o errexit
 # Shadow Gambit
 ###
 
-script_version=20231221.4
+script_version=20240408.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.28'
 
 GAME_ID='shadow-gambit'
 GAME_NAME='Shadow Gambit: The Cursed Crew'
@@ -145,25 +145,15 @@ fi
 # Extract game data
 
 archive_extraction_default
-(
-	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
-
-	# Prevent the inclusion of unwanted files
-	rm --force --recursive \
-		'commonappdata' \
-		'tmp'
-)
 
 # Include game data
 
-set_current_package 'PKG_DATA'
-icons_inclusion
+content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
 # Write launchers
 
-set_current_package 'PKG_BIN'
-launchers_write
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
