@@ -7,13 +7,20 @@ set -o errexit
 # Startopia
 ###
 
-script_version=20230925.1
+script_version=20240523.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.26'
+PLAYIT_COMPATIBILITY_LEVEL='2.28'
 
 GAME_ID='startopia'
 GAME_NAME='Startopia'
 
+GAME_ID_DEMO="${GAME_ID}-demo"
+GAME_NAME_DEMO="$GAME_NAME (demo)"
+
+## Archives
+
+### Full game
+
 ARCHIVE_BASE_0_NAME='setup_startopia_2.0.0.17.exe'
 ARCHIVE_BASE_0_MD5='4fe8d194afc1012e136ed3e82f1de171'
 ARCHIVE_BASE_0_TYPE='innosetup'
@@ -21,7 +28,18 @@ ARCHIVE_BASE_0_SIZE='600000'
 ARCHIVE_BASE_0_VERSION='1.01b-gog2.0.0.17'
 ARCHIVE_BASE_0_URL='https://www.gog.com/game/startopia'
 
+### Free demo
+
+ARCHIVE_BASE_DEMO_0_NAME='startopia_demo.exe'
+ARCHIVE_BASE_DEMO_0_MD5='2e170f8c4700b2d271ac2a6fac23920a'
+ARCHIVE_BASE_DEMO_0_TYPE='zip'
+ARCHIVE_BASE_DEMO_0_SIZE='149364'
+ARCHIVE_BASE_DEMO_0_VERSION='2001.5.15.1-archive.org'
+ARCHIVE_BASE_DEMO_0_URL='https://archive.org/details/startopia_demo'
+
+
 CONTENT_PATH_DEFAULT='app'
+CONTENT_PATH_DEFAULT_DEMO='.'
 CONTENT_GAME_BIN_FILES='
 binkw32.dll
 startopia.exe
@@ -37,6 +55,7 @@ text'
 CONTENT_DOC_DATA_FILES='
 eula
 weblinks
+*.doc
 *.html
 *.pdf
 *.rtf
@@ -47,17 +66,21 @@ profiles'
 USER_PERSISTENT_FILES='
 startopia.ini'
 
+WINE_VIRTUAL_DESKTOP='auto'
+
 APP_MAIN_EXE='startopia.exe'
 
-PACKAGES_LIST='PKG_BIN PKG_DATA'
+PACKAGES_LIST='
+PKG_BIN
+PKG_DATA'
 
 PKG_DATA_ID="${GAME_ID}-data"
+PKG_DATA_ID_DEMO="${GAME_ID_DEMO}-data"
 PKG_DATA_DESCRIPTION='data'
 
 PKG_BIN_ARCH='32'
 PKG_BIN_DEPS="$PKG_DATA_ID"
-
-## FIXME: This game can get display issues on some resolutions, when run on Wayland without using a virtual desktop.
+PKG_BIN_DEPS_DEMO="$PKG_DATA_ID_DEMO"
 
 # Load common functions
 
@@ -90,7 +113,14 @@ archive_extraction_default
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	# Generate minimal configuration file
+	## Free demo - Convert all file paths to lowercase.
+	case "$(current_archive)" in
+		('ARCHIVE_BASE_DEMO_'*)
+			tolower .
+		;;
+	esac
+
+	## Generate a minimal configuration file.
 	config_file='startopia.ini'
 	game_path="C:\\$(game_id)"
 	intro_path="${game_path}\\intro\\"
@@ -107,26 +137,18 @@ archive_extraction_default
 	EOF
 )
 
-# Include game icons
-
-PKG='PKG_DATA'
-icons_inclusion
-
 # Include game data
 
+content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
 # Write launchers
 
-PKG='PKG_BIN'
-launchers_write
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
 packages_generation
-
-# Print instructions
-
 print_instructions
 
 # Clean up
