@@ -13,9 +13,9 @@ set -o errexit
 # - Toxoids
 ###
 
-script_version=20240127.1
+script_version=20240620.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.29'
 
 GAME_ID='stellaris'
 GAME_NAME='Stellaris'
@@ -42,36 +42,36 @@ EXPANSION_NAME_TOXOIDS='Toxoids Species Pack'
 
 ## Plantoids
 
+ARCHIVE_BASE_PLANTOID_56_NAME='stellaris_plantoids_species_pack_3_12_5_74193.sh'
+ARCHIVE_BASE_PLANTOID_56_MD5='c97796440232a0afa39a793efae40c67'
+ARCHIVE_BASE_PLANTOID_56_SIZE='837'
+ARCHIVE_BASE_PLANTOID_56_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_PLANTOID_56_URL='https://www.gog.com/game/stellaris_plantoids_species_pack'
+
+ARCHIVE_BASE_PLANTOID_55_NAME='stellaris_plantoids_species_pack_3_12_4_1_74025.sh'
+ARCHIVE_BASE_PLANTOID_55_MD5='270742bc4ec4b9fdb95c6e2b9859bd39'
+ARCHIVE_BASE_PLANTOID_55_SIZE='837'
+ARCHIVE_BASE_PLANTOID_55_VERSION='3.12.4-gog74025'
+
+ARCHIVE_BASE_PLANTOID_54_NAME='stellaris_plantoids_species_pack_3_12_2_73401.sh'
+ARCHIVE_BASE_PLANTOID_54_MD5='733dc8f83132aa0ef864a9c05a79f928'
+ARCHIVE_BASE_PLANTOID_54_SIZE='837'
+ARCHIVE_BASE_PLANTOID_54_VERSION='3.12.2-gog73401'
+
+ARCHIVE_BASE_PLANTOID_53_NAME='stellaris_plantoids_species_pack_3_12_1_73183.sh'
+ARCHIVE_BASE_PLANTOID_53_MD5='5ddf59900abe04cd2b7c940a3578f80d'
+ARCHIVE_BASE_PLANTOID_53_SIZE='837'
+ARCHIVE_BASE_PLANTOID_53_VERSION='3.12.1-gog73183'
+
+ARCHIVE_BASE_PLANTOID_52_NAME='stellaris_plantoids_species_pack_3_11_3_0_72561.sh'
+ARCHIVE_BASE_PLANTOID_52_MD5='c301172fde38bcd14b9e7546f35e49d2'
+ARCHIVE_BASE_PLANTOID_52_SIZE='837'
+ARCHIVE_BASE_PLANTOID_52_VERSION='3.11.3-gog72561'
+
 ARCHIVE_BASE_PLANTOID_49_NAME='stellaris_plantoids_species_pack_3_10_4_70670.sh'
 ARCHIVE_BASE_PLANTOID_49_MD5='fc70ea7215520e885c61d072463b9be4'
 ARCHIVE_BASE_PLANTOID_49_SIZE='837'
 ARCHIVE_BASE_PLANTOID_49_VERSION='3.10.4-gog70670'
-ARCHIVE_BASE_PLANTOID_49_URL='https://www.gog.com/game/stellaris_plantoids_species_pack'
-
-ARCHIVE_BASE_PLANTOID_48_NAME='stellaris_plantoids_species_pack_3_10_4_69706.sh'
-ARCHIVE_BASE_PLANTOID_48_MD5='f95d0360d70f2c241ff8577c12145663'
-ARCHIVE_BASE_PLANTOID_48_SIZE='837'
-ARCHIVE_BASE_PLANTOID_48_VERSION='3.10.4-gog69706'
-
-ARCHIVE_BASE_PLANTOID_47_NAME='stellaris_plantoids_species_pack_3_10_3_69539.sh'
-ARCHIVE_BASE_PLANTOID_47_MD5='8df08ad91b367aee5a963564fa09d387'
-ARCHIVE_BASE_PLANTOID_47_SIZE='1156'
-ARCHIVE_BASE_PLANTOID_47_VERSION='3.10.3-gog69539'
-
-ARCHIVE_BASE_PLANTOID_46_NAME='stellaris_plantoids_species_pack_3_10_2_69346.sh'
-ARCHIVE_BASE_PLANTOID_46_MD5='838cf84e76f3dc9782874c6c32a2eb73'
-ARCHIVE_BASE_PLANTOID_46_SIZE='1156'
-ARCHIVE_BASE_PLANTOID_46_VERSION='3.10.2-gog69346'
-
-ARCHIVE_BASE_PLANTOID_45_NAME='stellaris_plantoids_species_pack_3_10_1_69202.sh'
-ARCHIVE_BASE_PLANTOID_45_MD5='f46acc22db074dabbfffdc552fe10ab3'
-ARCHIVE_BASE_PLANTOID_45_SIZE='1156'
-ARCHIVE_BASE_PLANTOID_45_VERSION='3.10.1-gog69202'
-
-ARCHIVE_BASE_PLANTOID_44_NAME='stellaris_plantoids_species_pack_3_10_0_2_68987.sh'
-ARCHIVE_BASE_PLANTOID_44_MD5='a6bde010ae32ebc8b7827d54dd873f29'
-ARCHIVE_BASE_PLANTOID_44_SIZE='1156'
-ARCHIVE_BASE_PLANTOID_44_VERSION='3.10.0.2-gog68987'
 
 ARCHIVE_BASE_PLANTOID_43_NAME='stellaris_plantoids_species_pack_3_9_3_68314.sh'
 ARCHIVE_BASE_PLANTOID_43_MD5='f38e8c826f876f52cea68b69f85ca079'
@@ -130,36 +130,36 @@ ARCHIVE_BASE_PLANTOID_19_VERSION='3.0.3-gog47193'
 
 ## Humanoids
 
+ARCHIVE_BASE_HUMANOIDS_56_NAME='stellaris_humanoids_species_pack_3_12_5_74193.sh'
+ARCHIVE_BASE_HUMANOIDS_56_MD5='f7fa5900c87f3fb8cd43d9dcead97de2'
+ARCHIVE_BASE_HUMANOIDS_56_SIZE='116312'
+ARCHIVE_BASE_HUMANOIDS_56_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_HUMANOIDS_56_URL='https://www.gog.com/game/stellaris_humanoids_species_pack'
+
+ARCHIVE_BASE_HUMANOIDS_55_NAME='stellaris_humanoids_species_pack_3_12_4_1_74025.sh'
+ARCHIVE_BASE_HUMANOIDS_55_MD5='001eda53219385a7c112a3f6ddaff7f9'
+ARCHIVE_BASE_HUMANOIDS_55_SIZE='116312'
+ARCHIVE_BASE_HUMANOIDS_55_VERSION='3.12.4-gog74025'
+
+ARCHIVE_BASE_HUMANOIDS_54_NAME='stellaris_humanoids_species_pack_3_12_2_73401.sh'
+ARCHIVE_BASE_HUMANOIDS_54_MD5='56a8b2c43e30b779ad0352bc21f23f63'
+ARCHIVE_BASE_HUMANOIDS_54_SIZE='116312'
+ARCHIVE_BASE_HUMANOIDS_54_VERSION='3.12.2-gog73401'
+
+ARCHIVE_BASE_HUMANOIDS_53_NAME='stellaris_humanoids_species_pack_3_12_1_73183.sh'
+ARCHIVE_BASE_HUMANOIDS_53_MD5='d3cbb81ac3c037f43e24f41d74f83c9f'
+ARCHIVE_BASE_HUMANOIDS_53_SIZE='116312'
+ARCHIVE_BASE_HUMANOIDS_53_VERSION='3.12.1-gog73183'
+
+ARCHIVE_BASE_HUMANOIDS_52_NAME='stellaris_humanoids_species_pack_3_11_3_0_72561.sh'
+ARCHIVE_BASE_HUMANOIDS_52_MD5='833ef910df4b00cfb7e3177b7525bee9'
+ARCHIVE_BASE_HUMANOIDS_52_SIZE='116312'
+ARCHIVE_BASE_HUMANOIDS_52_VERSION='3.11.3-gog72561'
+
 ARCHIVE_BASE_HUMANOIDS_49_NAME='stellaris_humanoids_species_pack_3_10_4_70670.sh'
 ARCHIVE_BASE_HUMANOIDS_49_MD5='515dd7f2ae1c68fe53a589f77b7af19c'
 ARCHIVE_BASE_HUMANOIDS_49_SIZE='116312'
 ARCHIVE_BASE_HUMANOIDS_49_VERSION='3.10.4-gog70670'
-ARCHIVE_BASE_HUMANOIDS_49_URL='https://www.gog.com/game/stellaris_humanoids_species_pack'
-
-ARCHIVE_BASE_HUMANOIDS_48_NAME='stellaris_humanoids_species_pack_3_10_4_69706.sh'
-ARCHIVE_BASE_HUMANOIDS_48_MD5='3c9e030365d288f26f8d3f6dbb3d9625'
-ARCHIVE_BASE_HUMANOIDS_48_SIZE='116312'
-ARCHIVE_BASE_HUMANOIDS_48_VERSION='3.10.4-gog69706'
-
-ARCHIVE_BASE_HUMANOIDS_47_NAME='stellaris_humanoids_species_pack_3_10_3_69539.sh'
-ARCHIVE_BASE_HUMANOIDS_47_MD5='2a7a49e7029dad68580992dc7fcc5030'
-ARCHIVE_BASE_HUMANOIDS_47_SIZE='116632'
-ARCHIVE_BASE_HUMANOIDS_47_VERSION='3.10.3-gog69539'
-
-ARCHIVE_BASE_HUMANOIDS_46_NAME='stellaris_humanoids_species_pack_3_10_2_69346.sh'
-ARCHIVE_BASE_HUMANOIDS_46_MD5='59ef453ddcc80b9fcddc07bdfbfaa4dd'
-ARCHIVE_BASE_HUMANOIDS_46_SIZE='116636'
-ARCHIVE_BASE_HUMANOIDS_46_VERSION='3.10.2-gog69346'
-
-ARCHIVE_BASE_HUMANOIDS_45_NAME='stellaris_humanoids_species_pack_3_10_1_69202.sh'
-ARCHIVE_BASE_HUMANOIDS_45_MD5='ec7e9435a832ba018b188834412be163'
-ARCHIVE_BASE_HUMANOIDS_45_SIZE='116636'
-ARCHIVE_BASE_HUMANOIDS_45_VERSION='3.10.1-gog69202'
-
-ARCHIVE_BASE_HUMANOIDS_44_NAME='stellaris_humanoids_species_pack_3_10_0_2_68987.sh'
-ARCHIVE_BASE_HUMANOIDS_44_MD5='3c81b11d1da6888915d7fcd4ceb3c51b'
-ARCHIVE_BASE_HUMANOIDS_44_SIZE='116636'
-ARCHIVE_BASE_HUMANOIDS_44_VERSION='3.10.0.2-gog68987'
 
 ARCHIVE_BASE_HUMANOIDS_43_NAME='stellaris_humanoids_species_pack_3_9_3_68314.sh'
 ARCHIVE_BASE_HUMANOIDS_43_MD5='d970689331dfae6ad559b4dd8d146080'
@@ -213,36 +213,36 @@ ARCHIVE_BASE_HUMANOIDS_19_VERSION='3.0.3-gog47193'
 
 ## Lithoids
 
+ARCHIVE_BASE_LITHOIDS_44_NAME='stellaris_lithoids_species_pack_3_12_5_74193.sh'
+ARCHIVE_BASE_LITHOIDS_44_MD5='bc4810ff3047e688c1ec0ae0991987ae'
+ARCHIVE_BASE_LITHOIDS_44_SIZE='52603'
+ARCHIVE_BASE_LITHOIDS_44_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_LITHOIDS_44_URL='https://www.gog.com/game/stellaris_lithoids_species_pack'
+
+ARCHIVE_BASE_LITHOIDS_43_NAME='stellaris_lithoids_species_pack_3_12_4_1_74025.sh'
+ARCHIVE_BASE_LITHOIDS_43_MD5='4fb488d3088126135d1fa6a2435e1165'
+ARCHIVE_BASE_LITHOIDS_43_SIZE='52603'
+ARCHIVE_BASE_LITHOIDS_43_VERSION='3.12.4-gog74025'
+
+ARCHIVE_BASE_LITHOIDS_42_NAME='stellaris_lithoids_species_pack_3_12_2_73401.sh'
+ARCHIVE_BASE_LITHOIDS_42_MD5='cdd908648182b22d1ec0661f35c9e8b9'
+ARCHIVE_BASE_LITHOIDS_42_SIZE='52603'
+ARCHIVE_BASE_LITHOIDS_42_VERSION='3.12.2-gog73401'
+
+ARCHIVE_BASE_LITHOIDS_41_NAME='stellaris_lithoids_species_pack_3_12_1_73183.sh'
+ARCHIVE_BASE_LITHOIDS_41_MD5='6d92087f30f2e219b11663ed3537e194'
+ARCHIVE_BASE_LITHOIDS_41_SIZE='52603'
+ARCHIVE_BASE_LITHOIDS_41_VERSION='3.12.1-gog73183'
+
+ARCHIVE_BASE_LITHOIDS_40_NAME='stellaris_lithoids_species_pack_3_11_3_0_72561.sh'
+ARCHIVE_BASE_LITHOIDS_40_MD5='8ca00268fd2b3b4fb611b65bc2f4edb7'
+ARCHIVE_BASE_LITHOIDS_40_SIZE='52603'
+ARCHIVE_BASE_LITHOIDS_40_VERSION='3.11.3-gog72561'
+
 ARCHIVE_BASE_LITHOIDS_37_NAME='stellaris_lithoids_species_pack_3_10_4_70670.sh'
 ARCHIVE_BASE_LITHOIDS_37_MD5='96caaa7c76349f34823372cc7f9dc769'
 ARCHIVE_BASE_LITHOIDS_37_SIZE='52603'
 ARCHIVE_BASE_LITHOIDS_37_VERSION='3.10.4-gog70670'
-ARCHIVE_BASE_LITHOIDS_37_URL='https://www.gog.com/game/stellaris_lithoids_species_pack'
-
-ARCHIVE_BASE_LITHOIDS_36_NAME='stellaris_lithoids_species_pack_3_10_4_69706.sh'
-ARCHIVE_BASE_LITHOIDS_36_MD5='b2bd55d83b031d26cad001cd34ede628'
-ARCHIVE_BASE_LITHOIDS_36_SIZE='52603'
-ARCHIVE_BASE_LITHOIDS_36_VERSION='3.10.4-gog69706'
-
-ARCHIVE_BASE_LITHOIDS_35_NAME='stellaris_lithoids_species_pack_3_10_3_69539.sh'
-ARCHIVE_BASE_LITHOIDS_35_MD5='eb77bfefd574709e2d5d68a3cee305bd'
-ARCHIVE_BASE_LITHOIDS_35_SIZE='52924'
-ARCHIVE_BASE_LITHOIDS_35_VERSION='3.10.3-gog69539'
-
-ARCHIVE_BASE_LITHOIDS_34_NAME='stellaris_lithoids_species_pack_3_10_2_69346.sh'
-ARCHIVE_BASE_LITHOIDS_34_MD5='f10dcb66e8e1de829d5b93654af83c34'
-ARCHIVE_BASE_LITHOIDS_34_SIZE='52928'
-ARCHIVE_BASE_LITHOIDS_34_VERSION='3.10.2-gog69346'
-
-ARCHIVE_BASE_LITHOIDS_33_NAME='stellaris_lithoids_species_pack_3_10_1_69202.sh'
-ARCHIVE_BASE_LITHOIDS_33_MD5='95a043b540c05e66d5aa6444cde39a78'
-ARCHIVE_BASE_LITHOIDS_33_SIZE='52924'
-ARCHIVE_BASE_LITHOIDS_33_VERSION='3.10.1-gog69202'
-
-ARCHIVE_BASE_LITHOIDS_32_NAME='stellaris_lithoids_species_pack_3_10_0_2_68987.sh'
-ARCHIVE_BASE_LITHOIDS_32_MD5='7b67f6a6bed2c9a78cf23ede66fa4a9d'
-ARCHIVE_BASE_LITHOIDS_32_SIZE='52924'
-ARCHIVE_BASE_LITHOIDS_32_VERSION='3.10.0.2-gog68987'
 
 ARCHIVE_BASE_LITHOIDS_31_NAME='stellaris_lithoids_species_pack_3_9_3_68314.sh'
 ARCHIVE_BASE_LITHOIDS_31_MD5='baecdaa00168fe891ff419b71334f313'
@@ -296,36 +296,36 @@ ARCHIVE_BASE_LITHOIDS_7_VERSION='3.0.3-gog47193'
 
 ## Necroids
 
+ARCHIVE_BASE_NECROIDS_29_NAME='stellaris_necroids_species_pack_3_12_5_74193.sh'
+ARCHIVE_BASE_NECROIDS_29_MD5='3df3d9f80ed1d79a2f0f412535b77d54'
+ARCHIVE_BASE_NECROIDS_29_SIZE='49209'
+ARCHIVE_BASE_NECROIDS_29_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_NECROIDS_29_URL='https://www.gog.com/game/stellaris_necroids_species_pack'
+
+ARCHIVE_BASE_NECROIDS_28_NAME='stellaris_necroids_species_pack_3_12_4_1_74025.sh'
+ARCHIVE_BASE_NECROIDS_28_MD5='25d7cabea1f2a2c3dae4f00bbae0fd49'
+ARCHIVE_BASE_NECROIDS_28_SIZE='49209'
+ARCHIVE_BASE_NECROIDS_28_VERSION='3.12.4-gog74025'
+
+ARCHIVE_BASE_NECROIDS_27_NAME='stellaris_necroids_species_pack_3_12_2_73401.sh'
+ARCHIVE_BASE_NECROIDS_27_MD5='bd3fc243e8b5f271f28e412707dc9a75'
+ARCHIVE_BASE_NECROIDS_27_SIZE='49209'
+ARCHIVE_BASE_NECROIDS_27_VERSION='3.12.2-gog73401'
+
+ARCHIVE_BASE_NECROIDS_26_NAME='stellaris_necroids_species_pack_3_12_1_73183.sh'
+ARCHIVE_BASE_NECROIDS_26_MD5='a5107b771305fda5b471a28366b81d47'
+ARCHIVE_BASE_NECROIDS_26_SIZE='49209'
+ARCHIVE_BASE_NECROIDS_26_VERSION='3.12.1-gog73183'
+
+ARCHIVE_BASE_NECROIDS_25_NAME='stellaris_necroids_species_pack_3_11_3_0_72561.sh'
+ARCHIVE_BASE_NECROIDS_25_MD5='d0f677482b688ebe46e0abf20ece8477'
+ARCHIVE_BASE_NECROIDS_25_SIZE='49209'
+ARCHIVE_BASE_NECROIDS_25_VERSION='3.11.3-gog72561'
+
 ARCHIVE_BASE_NECROIDS_22_NAME='stellaris_necroids_species_pack_3_10_4_70670.sh'
 ARCHIVE_BASE_NECROIDS_22_MD5='5549b1dfec82af2de64537ed751a1920'
 ARCHIVE_BASE_NECROIDS_22_SIZE='49209'
 ARCHIVE_BASE_NECROIDS_22_VERSION='3.10.4-gog70670'
-ARCHIVE_BASE_NECROIDS_22_URL='https://www.gog.com/game/stellaris_necroids_species_pack'
-
-ARCHIVE_BASE_NECROIDS_21_NAME='stellaris_necroids_species_pack_3_10_4_69706.sh'
-ARCHIVE_BASE_NECROIDS_21_MD5='4d085fb00b919e41b674e545b5249df3'
-ARCHIVE_BASE_NECROIDS_21_SIZE='49209'
-ARCHIVE_BASE_NECROIDS_21_VERSION='3.10.4-gog69706'
-
-ARCHIVE_BASE_NECROIDS_20_NAME='stellaris_necroids_species_pack_3_10_3_69539.sh'
-ARCHIVE_BASE_NECROIDS_20_MD5='2964d6e9254f558fe50c48a4b8109a05'
-ARCHIVE_BASE_NECROIDS_20_SIZE='49524'
-ARCHIVE_BASE_NECROIDS_20_VERSION='3.10.3-gog69539'
-
-ARCHIVE_BASE_NECROIDS_19_NAME='stellaris_necroids_species_pack_3_10_2_69346.sh'
-ARCHIVE_BASE_NECROIDS_19_MD5='911ef2256a0e267c194bfca7d0ec2216'
-ARCHIVE_BASE_NECROIDS_19_SIZE='49528'
-ARCHIVE_BASE_NECROIDS_19_VERSION='3.10.2-gog69346'
-
-ARCHIVE_BASE_NECROIDS_18_NAME='stellaris_necroids_species_pack_3_10_1_69202.sh'
-ARCHIVE_BASE_NECROIDS_18_MD5='a9478a35f71b02a14de72bda03692b34'
-ARCHIVE_BASE_NECROIDS_18_SIZE='49524'
-ARCHIVE_BASE_NECROIDS_18_VERSION='3.10.1-gog69202'
-
-ARCHIVE_BASE_NECROIDS_17_NAME='stellaris_necroids_species_pack_3_10_0_2_68987.sh'
-ARCHIVE_BASE_NECROIDS_17_MD5='3949c02f1d073b1174ae274a9a3998ff'
-ARCHIVE_BASE_NECROIDS_17_SIZE='49524'
-ARCHIVE_BASE_NECROIDS_17_VERSION='3.10.0.2-gog68987'
 
 ARCHIVE_BASE_NECROIDS_16_NAME='stellaris_necroids_species_pack_3_9_3_68314.sh'
 ARCHIVE_BASE_NECROIDS_16_MD5='8afbc28fb3af625dd145381e44fe7bde'
@@ -359,36 +359,36 @@ ARCHIVE_BASE_NECROIDS_2_VERSION='3.4.5-gog56913'
 
 ## Aquatics
 
+ARCHIVE_BASE_AQUATICS_27_NAME='stellaris_aquatics_species_pack_3_12_5_74193.sh'
+ARCHIVE_BASE_AQUATICS_27_MD5='0d9d2d2a38c60025b79e72011b52837c'
+ARCHIVE_BASE_AQUATICS_27_SIZE='57544'
+ARCHIVE_BASE_AQUATICS_27_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_AQUATICS_27_URL='https://www.gog.com/game/stellaris_aquatics_species_pack'
+
+ARCHIVE_BASE_AQUATICS_26_NAME='stellaris_aquatics_species_pack_3_12_4_1_74025.sh'
+ARCHIVE_BASE_AQUATICS_26_MD5='d7875e26717ae5a7c86c660f0f9408d2'
+ARCHIVE_BASE_AQUATICS_26_SIZE='57544'
+ARCHIVE_BASE_AQUATICS_26_VERSION='3.12.4-gog74025'
+
+ARCHIVE_BASE_AQUATICS_25_NAME='stellaris_aquatics_species_pack_3_12_2_73401.sh'
+ARCHIVE_BASE_AQUATICS_25_MD5='18bd0132d65536988134a53ce5ad1f63'
+ARCHIVE_BASE_AQUATICS_25_SIZE='57544'
+ARCHIVE_BASE_AQUATICS_25_VERSION='3.12.2-gog73401'
+
+ARCHIVE_BASE_AQUATICS_24_NAME='stellaris_aquatics_species_pack_3_12_1_73183.sh'
+ARCHIVE_BASE_AQUATICS_24_MD5='f57b66ee25468393a76333676b014401'
+ARCHIVE_BASE_AQUATICS_24_SIZE='57544'
+ARCHIVE_BASE_AQUATICS_24_VERSION='3.12.1-gog73183'
+
+ARCHIVE_BASE_AQUATICS_23_NAME='stellaris_aquatics_species_pack_3_11_3_0_72561.sh'
+ARCHIVE_BASE_AQUATICS_23_MD5='818beaf18d82951df0b1028eb0d7f78a'
+ARCHIVE_BASE_AQUATICS_23_SIZE='120876'
+ARCHIVE_BASE_AQUATICS_23_VERSION='3.11.3-gog72561'
+
 ARCHIVE_BASE_AQUATICS_20_NAME='stellaris_aquatics_species_pack_3_10_4_70670.sh'
 ARCHIVE_BASE_AQUATICS_20_MD5='335d95744fa5467cad87e276fb8d6997'
 ARCHIVE_BASE_AQUATICS_20_SIZE='120876'
 ARCHIVE_BASE_AQUATICS_20_VERSION='3.10.4-gog70670'
-ARCHIVE_BASE_AQUATICS_20_URL='https://www.gog.com/game/stellaris_aquatics_species_pack'
-
-ARCHIVE_BASE_AQUATICS_19_NAME='stellaris_aquatics_species_pack_3_10_4_69706.sh'
-ARCHIVE_BASE_AQUATICS_19_MD5='2fdb60088aa8acb3900a6efa98c55b07'
-ARCHIVE_BASE_AQUATICS_19_SIZE='120876'
-ARCHIVE_BASE_AQUATICS_19_VERSION='3.10.4-gog69706'
-
-ARCHIVE_BASE_AQUATICS_18_NAME='stellaris_aquatics_species_pack_3_10_3_69539.sh'
-ARCHIVE_BASE_AQUATICS_18_MD5='2f446801a28f11c448bdcad3c2ac9e17'
-ARCHIVE_BASE_AQUATICS_18_SIZE='121452'
-ARCHIVE_BASE_AQUATICS_18_VERSION='3.10.3-gog69539'
-
-ARCHIVE_BASE_AQUATICS_17_NAME='stellaris_aquatics_species_pack_3_10_2_69346.sh'
-ARCHIVE_BASE_AQUATICS_17_MD5='d90720ccd040de1dd649ea43f7f74d1a'
-ARCHIVE_BASE_AQUATICS_17_SIZE='121448'
-ARCHIVE_BASE_AQUATICS_17_VERSION='3.10.2-gog69346'
-
-ARCHIVE_BASE_AQUATICS_16_NAME='stellaris_aquatics_species_pack_3_10_1_69202.sh'
-ARCHIVE_BASE_AQUATICS_16_MD5='b542b48d85eba5667315557aca340278'
-ARCHIVE_BASE_AQUATICS_16_SIZE='121448'
-ARCHIVE_BASE_AQUATICS_16_VERSION='3.10.1-gog69202'
-
-ARCHIVE_BASE_AQUATICS_15_NAME='stellaris_aquatics_species_pack_3_10_0_2_68987.sh'
-ARCHIVE_BASE_AQUATICS_15_MD5='bf594d37a181e555dcfcbe772e45a650'
-ARCHIVE_BASE_AQUATICS_15_SIZE='121448'
-ARCHIVE_BASE_AQUATICS_15_VERSION='3.10.0.2-gog68987'
 
 ARCHIVE_BASE_AQUATICS_14_NAME='stellaris_aquatics_species_pack_3_9_3_68314.sh'
 ARCHIVE_BASE_AQUATICS_14_MD5='39294019e3f068916fea06f68e35b1ee'
@@ -422,36 +422,36 @@ ARCHIVE_BASE_AQUATICS_0_VERSION='3.4.5-gog56913'
 
 ## Toxoids
 
+ARCHIVE_BASE_TOXOIDS_20_NAME='stellaris_toxoids_species_pack_3_12_5_74193.sh'
+ARCHIVE_BASE_TOXOIDS_20_MD5='788f0afe85d1f90c91567e3958ddcae1'
+ARCHIVE_BASE_TOXOIDS_20_SIZE='41495'
+ARCHIVE_BASE_TOXOIDS_20_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_TOXOIDS_20_URL='https://www.gog.com/game/stellaris_toxoids_species_pack'
+
+ARCHIVE_BASE_TOXOIDS_19_NAME='stellaris_toxoids_species_pack_3_12_4_1_74025.sh'
+ARCHIVE_BASE_TOXOIDS_19_MD5='5ed15f2afe4197243b25a0c10c3d1f93'
+ARCHIVE_BASE_TOXOIDS_19_SIZE='41495'
+ARCHIVE_BASE_TOXOIDS_19_VERSION='3.12.4-gog74025'
+
+ARCHIVE_BASE_TOXOIDS_18_NAME='stellaris_toxoids_species_pack_3_12_2_73401.sh'
+ARCHIVE_BASE_TOXOIDS_18_MD5='154d04533036338269bbfe154432bd31'
+ARCHIVE_BASE_TOXOIDS_18_SIZE='41495'
+ARCHIVE_BASE_TOXOIDS_18_VERSION='3.12.2-gog73401'
+
+ARCHIVE_BASE_TOXOIDS_17_NAME='stellaris_toxoids_species_pack_3_12_1_73183.sh'
+ARCHIVE_BASE_TOXOIDS_17_MD5='43ea4a72bd0c90b37d18c472b209b097'
+ARCHIVE_BASE_TOXOIDS_17_SIZE='41495'
+ARCHIVE_BASE_TOXOIDS_17_VERSION='3.12.1-gog73183'
+
+ARCHIVE_BASE_TOXOIDS_16_NAME='stellaris_toxoids_species_pack_3_11_3_0_72561.sh'
+ARCHIVE_BASE_TOXOIDS_16_MD5='4dc7bf366e2e84febbe88f77057c018c'
+ARCHIVE_BASE_TOXOIDS_16_SIZE='41495'
+ARCHIVE_BASE_TOXOIDS_16_VERSION='3.11.3-gog72561'
+
 ARCHIVE_BASE_TOXOIDS_13_NAME='stellaris_toxoids_species_pack_3_10_4_70670.sh'
 ARCHIVE_BASE_TOXOIDS_13_MD5='ee41aba19af2f2f91bbe3c156bf614f5'
 ARCHIVE_BASE_TOXOIDS_13_SIZE='41495'
 ARCHIVE_BASE_TOXOIDS_13_VERSION='3.10.4-gog70670'
-ARCHIVE_BASE_TOXOIDS_13_URL='https://www.gog.com/game/stellaris_toxoids_species_pack'
-
-ARCHIVE_BASE_TOXOIDS_12_NAME='stellaris_toxoids_species_pack_3_10_4_69706.sh'
-ARCHIVE_BASE_TOXOIDS_12_MD5='89360920313849a557d4237be4c21dae'
-ARCHIVE_BASE_TOXOIDS_12_SIZE='41495'
-ARCHIVE_BASE_TOXOIDS_12_VERSION='3.10.4-gog69706'
-
-ARCHIVE_BASE_TOXOIDS_11_NAME='stellaris_toxoids_species_pack_3_10_3_69539.sh'
-ARCHIVE_BASE_TOXOIDS_11_MD5='c9c63f397711deb35babe3cb51620723'
-ARCHIVE_BASE_TOXOIDS_11_SIZE='41812'
-ARCHIVE_BASE_TOXOIDS_11_VERSION='3.10.3-gog69539'
-
-ARCHIVE_BASE_TOXOIDS_10_NAME='stellaris_toxoids_species_pack_3_10_2_69346.sh'
-ARCHIVE_BASE_TOXOIDS_10_MD5='9d31ec6ee301e4b8753cc105fd6e33dc'
-ARCHIVE_BASE_TOXOIDS_10_SIZE='41812'
-ARCHIVE_BASE_TOXOIDS_10_VERSION='3.10.2-gog69346'
-
-ARCHIVE_BASE_TOXOIDS_9_NAME='stellaris_toxoids_species_pack_3_10_1_69202.sh'
-ARCHIVE_BASE_TOXOIDS_9_MD5='ff0eea40c4c5a3d94a137236ce5c6d9e'
-ARCHIVE_BASE_TOXOIDS_9_SIZE='41812'
-ARCHIVE_BASE_TOXOIDS_9_VERSION='3.10.1-gog69202'
-
-ARCHIVE_BASE_TOXOIDS_8_NAME='stellaris_toxoids_species_pack_3_10_0_2_68987.sh'
-ARCHIVE_BASE_TOXOIDS_8_MD5='64c56e55ccfd2fb146425982b8d8e852'
-ARCHIVE_BASE_TOXOIDS_8_SIZE='41812'
-ARCHIVE_BASE_TOXOIDS_8_VERSION='3.10.0.2-gog68987'
 
 ARCHIVE_BASE_TOXOIDS_7_NAME='stellaris_toxoids_species_pack_3_9_3_68314.sh'
 ARCHIVE_BASE_TOXOIDS_7_MD5='69ee5d18ffe310c64ee61934ec64aa1f'
