@@ -12,9 +12,9 @@ set -o errexit
 # - First Contact
 ###
 
-script_version=20240127.1
+script_version=20240620.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.29'
 
 GAME_ID='stellaris'
 GAME_NAME='Stellaris'
@@ -38,36 +38,36 @@ EXPANSION_NAME_FIRSTCONTACT='First Contact Story Pack'
 
 ## Leviathans
 
+ARCHIVE_BASE_LEVIATHANS_56_NAME='stellaris_leviathans_story_pack_3_12_5_74193.sh'
+ARCHIVE_BASE_LEVIATHANS_56_MD5='8ab8f647d2405c443ee699b1ec3e17b4'
+ARCHIVE_BASE_LEVIATHANS_56_SIZE='58426'
+ARCHIVE_BASE_LEVIATHANS_56_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_LEVIATHANS_56_URL='https://www.gog.com/game/stellaris_leviathans_story_pack'
+
+ARCHIVE_BASE_LEVIATHANS_55_NAME='stellaris_leviathans_story_pack_3_12_4_1_74025.sh'
+ARCHIVE_BASE_LEVIATHANS_55_MD5='5c7db0bc37635d28e8365fca38ff3335'
+ARCHIVE_BASE_LEVIATHANS_55_SIZE='58426'
+ARCHIVE_BASE_LEVIATHANS_55_VERSION='3.12.4-gog74025'
+
+ARCHIVE_BASE_LEVIATHANS_54_NAME='stellaris_leviathans_story_pack_3_12_2_73401.sh'
+ARCHIVE_BASE_LEVIATHANS_54_MD5='cac93c6dbb81c13c381701a4589f914b'
+ARCHIVE_BASE_LEVIATHANS_54_SIZE='58426'
+ARCHIVE_BASE_LEVIATHANS_54_VERSION='3.12.2-gog73401'
+
+ARCHIVE_BASE_LEVIATHANS_53_NAME='stellaris_leviathans_story_pack_3_12_1_73183.sh'
+ARCHIVE_BASE_LEVIATHANS_53_MD5='fda0c7971c8c791e4498ffa019243920'
+ARCHIVE_BASE_LEVIATHANS_53_SIZE='58426'
+ARCHIVE_BASE_LEVIATHANS_53_VERSION='3.12.1-gog73183'
+
+ARCHIVE_BASE_LEVIATHANS_52_NAME='stellaris_leviathans_story_pack_3_11_3_0_72561.sh'
+ARCHIVE_BASE_LEVIATHANS_52_MD5='bbdede0f81d260b3225f671518d6f135'
+ARCHIVE_BASE_LEVIATHANS_52_SIZE='58426'
+ARCHIVE_BASE_LEVIATHANS_52_VERSION='3.11.3-gog72561'
+
 ARCHIVE_BASE_LEVIATHANS_49_NAME='stellaris_leviathans_story_pack_3_10_4_70670.sh'
 ARCHIVE_BASE_LEVIATHANS_49_MD5='ca7bd55fd1121dff315cf4bdc748ce5c'
 ARCHIVE_BASE_LEVIATHANS_49_SIZE='58426'
 ARCHIVE_BASE_LEVIATHANS_49_VERSION='3.10.4-gog70670'
-ARCHIVE_BASE_LEVIATHANS_49_URL='https://www.gog.com/game/stellaris_leviathans_story_pack'
-
-ARCHIVE_BASE_LEVIATHANS_48_NAME='stellaris_leviathans_story_pack_3_10_4_69706.sh'
-ARCHIVE_BASE_LEVIATHANS_48_MD5='9512b0d6532cd54faa9b1a91ecf1f160'
-ARCHIVE_BASE_LEVIATHANS_48_SIZE='58426'
-ARCHIVE_BASE_LEVIATHANS_48_VERSION='3.10.4-gog69706'
-
-ARCHIVE_BASE_LEVIATHANS_47_NAME='stellaris_leviathans_story_pack_3_10_3_69539.sh'
-ARCHIVE_BASE_LEVIATHANS_47_MD5='fd84836e6800dc4abf170de4a6b5054b'
-ARCHIVE_BASE_LEVIATHANS_47_SIZE='58744'
-ARCHIVE_BASE_LEVIATHANS_47_VERSION='3.10.3-gog69539'
-
-ARCHIVE_BASE_LEVIATHANS_46_NAME='stellaris_leviathans_story_pack_3_10_2_69346.sh'
-ARCHIVE_BASE_LEVIATHANS_46_MD5='e222df45bd9570c5c1551351d0212c9a'
-ARCHIVE_BASE_LEVIATHANS_46_SIZE='58744'
-ARCHIVE_BASE_LEVIATHANS_46_VERSION='3.10.2-gog69346'
-
-ARCHIVE_BASE_LEVIATHANS_45_NAME='stellaris_leviathans_story_pack_3_10_1_69202.sh'
-ARCHIVE_BASE_LEVIATHANS_45_MD5='f598f3ad41111dd3deb9c3adfd959d1d'
-ARCHIVE_BASE_LEVIATHANS_45_SIZE='58744'
-ARCHIVE_BASE_LEVIATHANS_45_VERSION='3.10.1-gog69202'
-
-ARCHIVE_BASE_LEVIATHANS_44_NAME='stellaris_leviathans_story_pack_3_10_0_2_68987.sh'
-ARCHIVE_BASE_LEVIATHANS_44_MD5='abcf0e606c6a1fe3e02f0c89e886625e'
-ARCHIVE_BASE_LEVIATHANS_44_SIZE='58744'
-ARCHIVE_BASE_LEVIATHANS_44_VERSION='3.10.0.2-gog68987'
 
 ARCHIVE_BASE_LEVIATHANS_43_NAME='stellaris_leviathans_story_pack_3_9_3_68314.sh'
 ARCHIVE_BASE_LEVIATHANS_43_MD5='12ed6b4e72c61d7d5a2223acfe3dec45'
@@ -121,36 +121,36 @@ ARCHIVE_BASE_LEVIATHANS_19_VERSION='3.0.3-gog47193'
 
 ## Synthetic Dawn
 
+ARCHIVE_BASE_SYNTHETICDAWN_55_NAME='stellaris_synthetic_dawn_story_pack_3_12_5_74193.sh'
+ARCHIVE_BASE_SYNTHETICDAWN_55_MD5='28f5282f2422cce01ca868a906eb499c'
+ARCHIVE_BASE_SYNTHETICDAWN_55_SIZE='48244'
+ARCHIVE_BASE_SYNTHETICDAWN_55_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_SYNTHETICDAWN_55_URL='https://www.gog.com/game/stellaris_synthetic_dawn_story_pack'
+
+ARCHIVE_BASE_SYNTHETICDAWN_54_NAME='stellaris_synthetic_dawn_story_pack_3_12_4_1_74025.sh'
+ARCHIVE_BASE_SYNTHETICDAWN_54_MD5='bd346298812a39a65efbc8a9fda6c903'
+ARCHIVE_BASE_SYNTHETICDAWN_54_SIZE='48244'
+ARCHIVE_BASE_SYNTHETICDAWN_54_VERSION='3.12.4-gog74025'
+
+ARCHIVE_BASE_SYNTHETICDAWN_53_NAME='stellaris_synthetic_dawn_story_pack_3_12_2_73401.sh'
+ARCHIVE_BASE_SYNTHETICDAWN_53_MD5='f1e7049e5e3e88794f8bd5935cb08e35'
+ARCHIVE_BASE_SYNTHETICDAWN_53_SIZE='48244'
+ARCHIVE_BASE_SYNTHETICDAWN_53_VERSION='3.12.2-gog73401'
+
+ARCHIVE_BASE_SYNTHETICDAWN_52_NAME='stellaris_synthetic_dawn_story_pack_3_12_1_73183.sh'
+ARCHIVE_BASE_SYNTHETICDAWN_52_MD5='54a9eaf01bcdd37c8f5474fa0d0cf564'
+ARCHIVE_BASE_SYNTHETICDAWN_52_SIZE='48244'
+ARCHIVE_BASE_SYNTHETICDAWN_52_VERSION='3.12.1-gog73183'
+
+ARCHIVE_BASE_SYNTHETICDAWN_51_NAME='stellaris_synthetic_dawn_story_pack_3_11_3_0_72561.sh'
+ARCHIVE_BASE_SYNTHETICDAWN_51_MD5='dacbf32f6358906934c4168ad06fff0d'
+ARCHIVE_BASE_SYNTHETICDAWN_51_SIZE='48244'
+ARCHIVE_BASE_SYNTHETICDAWN_51_VERSION='3.11.3-gog72561'
+
 ARCHIVE_BASE_SYNTHETICDAWN_48_NAME='stellaris_synthetic_dawn_story_pack_3_10_4_70670.sh'
 ARCHIVE_BASE_SYNTHETICDAWN_48_MD5='4b16f920acc6b2257386f020192aafce'
 ARCHIVE_BASE_SYNTHETICDAWN_48_SIZE='48244'
 ARCHIVE_BASE_SYNTHETICDAWN_48_VERSION='3.10.4-gog70670'
-ARCHIVE_BASE_SYNTHETICDAWN_48_URL='https://www.gog.com/game/stellaris_synthetic_dawn_story_pack'
-
-ARCHIVE_BASE_SYNTHETICDAWN_47_NAME='stellaris_synthetic_dawn_story_pack_3_10_4_69706.sh'
-ARCHIVE_BASE_SYNTHETICDAWN_47_MD5='78444fc5f2cfc20eca1cdfcc1ae3eb88'
-ARCHIVE_BASE_SYNTHETICDAWN_47_SIZE='48244'
-ARCHIVE_BASE_SYNTHETICDAWN_47_VERSION='3.10.4-gog69706'
-
-ARCHIVE_BASE_SYNTHETICDAWN_46_NAME='stellaris_synthetic_dawn_story_pack_3_10_3_69539.sh'
-ARCHIVE_BASE_SYNTHETICDAWN_46_MD5='f05613f1b03e6ca1aa197c6c1f7d55f9'
-ARCHIVE_BASE_SYNTHETICDAWN_46_SIZE='48564'
-ARCHIVE_BASE_SYNTHETICDAWN_46_VERSION='3.10.3-gog69539'
-
-ARCHIVE_BASE_SYNTHETICDAWN_45_NAME='stellaris_synthetic_dawn_story_pack_3_10_2_69346.sh'
-ARCHIVE_BASE_SYNTHETICDAWN_45_MD5='05a5d1fc9874124dd26b0cb01ed2619f'
-ARCHIVE_BASE_SYNTHETICDAWN_45_SIZE='48564'
-ARCHIVE_BASE_SYNTHETICDAWN_45_VERSION='3.10.2-gog69346'
-
-ARCHIVE_BASE_SYNTHETICDAWN_44_NAME='stellaris_synthetic_dawn_story_pack_3_10_1_69202.sh'
-ARCHIVE_BASE_SYNTHETICDAWN_44_MD5='890a5306863d5e1d800b383273adc3e8'
-ARCHIVE_BASE_SYNTHETICDAWN_44_SIZE='48564'
-ARCHIVE_BASE_SYNTHETICDAWN_44_VERSION='3.10.1-gog69202'
-
-ARCHIVE_BASE_SYNTHETICDAWN_43_NAME='stellaris_synthetic_dawn_story_pack_3_10_0_2_68987.sh'
-ARCHIVE_BASE_SYNTHETICDAWN_43_MD5='f5667ee774fe9387250a457a458c04a9'
-ARCHIVE_BASE_SYNTHETICDAWN_43_SIZE='48564'
-ARCHIVE_BASE_SYNTHETICDAWN_43_VERSION='3.10.0.2-gog68987'
 
 ARCHIVE_BASE_SYNTHETICDAWN_42_NAME='stellaris_synthetic_dawn_story_pack_3_9_3_68314.sh'
 ARCHIVE_BASE_SYNTHETICDAWN_42_MD5='b2f35b4c887634e98fbce5e737dd78d1'
@@ -204,36 +204,36 @@ ARCHIVE_BASE_SYNTHETICDAWN_18_VERSION='3.0.3-gog47193'
 
 ## Distant Stars
 
+ARCHIVE_BASE_DISTANTSTARS_55_NAME='stellaris_distant_stars_story_pack_3_12_5_74193.sh'
+ARCHIVE_BASE_DISTANTSTARS_55_MD5='be7d046f1e0165f607e0d19cf28eddc9'
+ARCHIVE_BASE_DISTANTSTARS_55_SIZE='20832'
+ARCHIVE_BASE_DISTANTSTARS_55_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_DISTANTSTARS_55_URL='https://www.gog.com/game/stellaris_distant_stars_story_pack'
+
+ARCHIVE_BASE_DISTANTSTARS_54_NAME='stellaris_distant_stars_story_pack_3_12_4_1_74025.sh'
+ARCHIVE_BASE_DISTANTSTARS_54_MD5='8be4da5035ba2d6942beb9734d934ed4'
+ARCHIVE_BASE_DISTANTSTARS_54_SIZE='20832'
+ARCHIVE_BASE_DISTANTSTARS_54_VERSION='3.12.4-gog74025'
+
+ARCHIVE_BASE_DISTANTSTARS_53_NAME='stellaris_distant_stars_story_pack_3_12_2_73401.sh'
+ARCHIVE_BASE_DISTANTSTARS_53_MD5='7f4fc7d101558aeb53f0ce76d40f1ac6'
+ARCHIVE_BASE_DISTANTSTARS_53_SIZE='20832'
+ARCHIVE_BASE_DISTANTSTARS_53_VERSION='3.12.2-gog73401'
+
+ARCHIVE_BASE_DISTANTSTARS_52_NAME='stellaris_distant_stars_story_pack_3_12_1_73183.sh'
+ARCHIVE_BASE_DISTANTSTARS_52_MD5='4fc5f1299cdde303204547ff089b29f9'
+ARCHIVE_BASE_DISTANTSTARS_52_SIZE='20832'
+ARCHIVE_BASE_DISTANTSTARS_52_VERSION='3.12.1-gog73183'
+
+ARCHIVE_BASE_DISTANTSTARS_51_NAME='stellaris_distant_stars_story_pack_3_11_3_0_72561.sh'
+ARCHIVE_BASE_DISTANTSTARS_51_MD5='1c05d748caac4118b22b1e7524936427'
+ARCHIVE_BASE_DISTANTSTARS_51_SIZE='20832'
+ARCHIVE_BASE_DISTANTSTARS_51_VERSION='3.11.3-gog72561'
+
 ARCHIVE_BASE_DISTANTSTARS_48_NAME='stellaris_distant_stars_story_pack_3_10_4_70670.sh'
 ARCHIVE_BASE_DISTANTSTARS_48_MD5='35b7b4c4e536fdefae1668c74e3932cc'
 ARCHIVE_BASE_DISTANTSTARS_48_SIZE='20832'
 ARCHIVE_BASE_DISTANTSTARS_48_VERSION='3.10.4-gog70670'
-ARCHIVE_BASE_DISTANTSTARS_48_URL='https://www.gog.com/game/stellaris_distant_stars_story_pack'
-
-ARCHIVE_BASE_DISTANTSTARS_47_NAME='stellaris_distant_stars_story_pack_3_10_4_69706.sh'
-ARCHIVE_BASE_DISTANTSTARS_47_MD5='8ae326da848b2c9febb600b2b68bc3bd'
-ARCHIVE_BASE_DISTANTSTARS_47_SIZE='20832'
-ARCHIVE_BASE_DISTANTSTARS_47_VERSION='3.10.4-gog69706'
-
-ARCHIVE_BASE_DISTANTSTARS_46_NAME='stellaris_distant_stars_story_pack_3_10_3_69539.sh'
-ARCHIVE_BASE_DISTANTSTARS_46_MD5='042fca80a8b65180c7d384142a35726f'
-ARCHIVE_BASE_DISTANTSTARS_46_SIZE='21148'
-ARCHIVE_BASE_DISTANTSTARS_46_VERSION='3.10.3-gog69539'
-
-ARCHIVE_BASE_DISTANTSTARS_45_NAME='stellaris_distant_stars_story_pack_3_10_2_69346.sh'
-ARCHIVE_BASE_DISTANTSTARS_45_MD5='95df62a0f9f366341b71a47a969f08ad'
-ARCHIVE_BASE_DISTANTSTARS_45_SIZE='21148'
-ARCHIVE_BASE_DISTANTSTARS_45_VERSION='3.10.2-gog69346'
-
-ARCHIVE_BASE_DISTANTSTARS_44_NAME='stellaris_distant_stars_story_pack_3_10_1_69202.sh'
-ARCHIVE_BASE_DISTANTSTARS_44_MD5='dded9ea4d706cf390388acac2784e767'
-ARCHIVE_BASE_DISTANTSTARS_44_SIZE='21148'
-ARCHIVE_BASE_DISTANTSTARS_44_VERSION='3.10.1-gog69202'
-
-ARCHIVE_BASE_DISTANTSTARS_43_NAME='stellaris_distant_stars_story_pack_3_10_0_2_68987.sh'
-ARCHIVE_BASE_DISTANTSTARS_43_MD5='ff3a4082c63e06295ddb436ae5a3964a'
-ARCHIVE_BASE_DISTANTSTARS_43_SIZE='21148'
-ARCHIVE_BASE_DISTANTSTARS_43_VERSION='3.10.0.2-gog68987'
 
 ARCHIVE_BASE_DISTANTSTARS_42_NAME='stellaris_distant_stars_story_pack_3_9_3_68314.sh'
 ARCHIVE_BASE_DISTANTSTARS_42_MD5='9a03b641cc29f77008530d21e64f5232'
@@ -287,36 +287,36 @@ ARCHIVE_BASE_DISTANTSTARS_18_VERSION='3.0.3-gog47193'
 
 ## Ancient Relics
 
+ARCHIVE_BASE_ANCIENTRELICS_44_NAME='stellaris_ancient_relics_3_12_5_74193.sh'
+ARCHIVE_BASE_ANCIENTRELICS_44_MD5='35a896e2d8a9044a15898e9f55a39d47'
+ARCHIVE_BASE_ANCIENTRELICS_44_SIZE='32739'
+ARCHIVE_BASE_ANCIENTRELICS_44_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_ANCIENTRELICS_44_URL='https://www.gog.com/game/stellaris_ancient_relics_story_pack'
+
+ARCHIVE_BASE_ANCIENTRELICS_43_NAME='stellaris_ancient_relics_3_12_4_1_74025.sh'
+ARCHIVE_BASE_ANCIENTRELICS_43_MD5='f38b960e9a6ea6bf98a5399df5835dcc'
+ARCHIVE_BASE_ANCIENTRELICS_43_SIZE='32739'
+ARCHIVE_BASE_ANCIENTRELICS_43_VERSION='3.12.4-gog74025'
+
+ARCHIVE_BASE_ANCIENTRELICS_42_NAME='stellaris_ancient_relics_3_12_2_73401.sh'
+ARCHIVE_BASE_ANCIENTRELICS_42_MD5='c5105c5a45acaace8b70fd534507c2e2'
+ARCHIVE_BASE_ANCIENTRELICS_42_SIZE='32739'
+ARCHIVE_BASE_ANCIENTRELICS_42_VERSION='3.12.2-gog73401'
+
+ARCHIVE_BASE_ANCIENTRELICS_41_NAME='stellaris_ancient_relics_3_12_1_73183.sh'
+ARCHIVE_BASE_ANCIENTRELICS_41_MD5='cfdee2034c7b1fd10644f3cb95e2fe93'
+ARCHIVE_BASE_ANCIENTRELICS_41_SIZE='32739'
+ARCHIVE_BASE_ANCIENTRELICS_41_VERSION='3.12.1-gog73183'
+
+ARCHIVE_BASE_ANCIENTRELICS_40_NAME='stellaris_ancient_relics_3_11_3_0_72561.sh'
+ARCHIVE_BASE_ANCIENTRELICS_40_MD5='a1468916582d7e7ad9c73ad58d2a37ec'
+ARCHIVE_BASE_ANCIENTRELICS_40_SIZE='32739'
+ARCHIVE_BASE_ANCIENTRELICS_40_VERSION='3.11.3-gog72561'
+
 ARCHIVE_BASE_ANCIENTRELICS_37_NAME='stellaris_ancient_relics_3_10_4_70670.sh'
 ARCHIVE_BASE_ANCIENTRELICS_37_MD5='dacebe45d724aa535d28dc73fd2b78ab'
 ARCHIVE_BASE_ANCIENTRELICS_37_SIZE='32739'
 ARCHIVE_BASE_ANCIENTRELICS_37_VERSION='3.10.4-gog70670'
-ARCHIVE_BASE_ANCIENTRELICS_37_URL='https://www.gog.com/game/stellaris_ancient_relics_story_pack'
-
-ARCHIVE_BASE_ANCIENTRELICS_36_NAME='stellaris_ancient_relics_3_10_4_69706.sh'
-ARCHIVE_BASE_ANCIENTRELICS_36_MD5='81f8e0d110f8c77538bf420a9d384b61'
-ARCHIVE_BASE_ANCIENTRELICS_36_SIZE='32739'
-ARCHIVE_BASE_ANCIENTRELICS_36_VERSION='3.10.4-gog69706'
-
-ARCHIVE_BASE_ANCIENTRELICS_35_NAME='stellaris_ancient_relics_3_10_3_69539.sh'
-ARCHIVE_BASE_ANCIENTRELICS_35_MD5='eb1b6ff1d4d61648043d6f528787ecf8'
-ARCHIVE_BASE_ANCIENTRELICS_35_SIZE='33060'
-ARCHIVE_BASE_ANCIENTRELICS_35_VERSION='3.10.3-gog69539'
-
-ARCHIVE_BASE_ANCIENTRELICS_34_NAME='stellaris_ancient_relics_3_10_2_69346.sh'
-ARCHIVE_BASE_ANCIENTRELICS_34_MD5='b413c0b5132dcd8346b3f6ff7b5582e4'
-ARCHIVE_BASE_ANCIENTRELICS_34_SIZE='33060'
-ARCHIVE_BASE_ANCIENTRELICS_34_VERSION='3.10.2-gog69346'
-
-ARCHIVE_BASE_ANCIENTRELICS_33_NAME='stellaris_ancient_relics_3_10_1_69202.sh'
-ARCHIVE_BASE_ANCIENTRELICS_33_MD5='83283896b79b4b81325f62a5a2b83281'
-ARCHIVE_BASE_ANCIENTRELICS_33_SIZE='33060'
-ARCHIVE_BASE_ANCIENTRELICS_33_VERSION='3.10.1-gog69202'
-
-ARCHIVE_BASE_ANCIENTRELICS_32_NAME='stellaris_ancient_relics_3_10_0_2_68987.sh'
-ARCHIVE_BASE_ANCIENTRELICS_32_MD5='b6eb34e2fcf75b524dae760a30ee802b'
-ARCHIVE_BASE_ANCIENTRELICS_32_SIZE='33060'
-ARCHIVE_BASE_ANCIENTRELICS_32_VERSION='3.10.0.2-gog68987'
 
 ARCHIVE_BASE_ANCIENTRELICS_31_NAME='stellaris_ancient_relics_3_9_3_68314.sh'
 ARCHIVE_BASE_ANCIENTRELICS_31_MD5='19909812633ca0d83ad774683f60451f'
@@ -370,36 +370,36 @@ ARCHIVE_BASE_ANCIENTRELICS_7_VERSION='3.0.3-gog47193'
 
 ## First Contact
 
+ARCHIVE_BASE_FIRSTCONTACT_18_NAME='stellaris_first_contact_story_pack_3_12_5_74193.sh'
+ARCHIVE_BASE_FIRSTCONTACT_18_MD5='d3e6622881abe21c5883e5fa61988f6b'
+ARCHIVE_BASE_FIRSTCONTACT_18_SIZE='832'
+ARCHIVE_BASE_FIRSTCONTACT_18_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_FIRSTCONTACT_18_URL='https://www.gog.com/game/stellaris_first_contact_story_pack'
+
+ARCHIVE_BASE_FIRSTCONTACT_17_NAME='stellaris_first_contact_story_pack_3_12_4_1_74025.sh'
+ARCHIVE_BASE_FIRSTCONTACT_17_MD5='d6f3195ac93b8df4b61bad706779b657'
+ARCHIVE_BASE_FIRSTCONTACT_17_SIZE='832'
+ARCHIVE_BASE_FIRSTCONTACT_17_VERSION='3.12.4-gog74025'
+
+ARCHIVE_BASE_FIRSTCONTACT_16_NAME='stellaris_first_contact_story_pack_3_12_2_73401.sh'
+ARCHIVE_BASE_FIRSTCONTACT_16_MD5='97d442da8c602c3da7db7627eb75361d'
+ARCHIVE_BASE_FIRSTCONTACT_16_SIZE='832'
+ARCHIVE_BASE_FIRSTCONTACT_16_VERSION='3.12.2-gog73401'
+
+ARCHIVE_BASE_FIRSTCONTACT_15_NAME='stellaris_first_contact_story_pack_3_12_1_73183.sh'
+ARCHIVE_BASE_FIRSTCONTACT_15_MD5='7be564ef8312307a1373908d11731835'
+ARCHIVE_BASE_FIRSTCONTACT_15_SIZE='832'
+ARCHIVE_BASE_FIRSTCONTACT_15_VERSION='3.12.1-gog73183'
+
+ARCHIVE_BASE_FIRSTCONTACT_14_NAME='stellaris_first_contact_story_pack_3_11_3_0_72561.sh'
+ARCHIVE_BASE_FIRSTCONTACT_14_MD5='946d0530c559cc4275177143f808a4e6'
+ARCHIVE_BASE_FIRSTCONTACT_14_SIZE='832'
+ARCHIVE_BASE_FIRSTCONTACT_14_VERSION='3.11.3-gog72561'
+
 ARCHIVE_BASE_FIRSTCONTACT_11_NAME='stellaris_first_contact_story_pack_3_10_4_70670.sh'
 ARCHIVE_BASE_FIRSTCONTACT_11_MD5='aa77a6af433d0ed023357b1af69876ce'
 ARCHIVE_BASE_FIRSTCONTACT_11_SIZE='832'
 ARCHIVE_BASE_FIRSTCONTACT_11_VERSION='3.10.4-gog70670'
-ARCHIVE_BASE_FIRSTCONTACT_11_URL='https://www.gog.com/game/stellaris_first_contact_story_pack'
-
-ARCHIVE_BASE_FIRSTCONTACT_10_NAME='stellaris_first_contact_story_pack_3_10_4_69706.sh'
-ARCHIVE_BASE_FIRSTCONTACT_10_MD5='5e1666673ecb61afec241ae9bd885d02'
-ARCHIVE_BASE_FIRSTCONTACT_10_SIZE='832'
-ARCHIVE_BASE_FIRSTCONTACT_10_VERSION='3.10.4-gog69706'
-
-ARCHIVE_BASE_FIRSTCONTACT_9_NAME='stellaris_first_contact_story_pack_3_10_3_69539.sh'
-ARCHIVE_BASE_FIRSTCONTACT_9_MD5='e0c09af6f7786b74d103d384bef9c062'
-ARCHIVE_BASE_FIRSTCONTACT_9_SIZE='1152'
-ARCHIVE_BASE_FIRSTCONTACT_9_VERSION='3.10.3-gog69539'
-
-ARCHIVE_BASE_FIRSTCONTACT_8_NAME='stellaris_first_contact_story_pack_3_10_2_69346.sh'
-ARCHIVE_BASE_FIRSTCONTACT_8_MD5='415a0c6f040110d37b814aba309bde77'
-ARCHIVE_BASE_FIRSTCONTACT_8_SIZE='1152'
-ARCHIVE_BASE_FIRSTCONTACT_8_VERSION='3.10.2-gog69346'
-
-ARCHIVE_BASE_FIRSTCONTACT_7_NAME='stellaris_first_contact_story_pack_3_10_1_69202.sh'
-ARCHIVE_BASE_FIRSTCONTACT_7_MD5='6645fe45272746e062a182494b07e001'
-ARCHIVE_BASE_FIRSTCONTACT_7_SIZE='1152'
-ARCHIVE_BASE_FIRSTCONTACT_7_VERSION='3.10.1-gog69202'
-
-ARCHIVE_BASE_FIRSTCONTACT_6_NAME='stellaris_first_contact_story_pack_3_10_0_2_68987.sh'
-ARCHIVE_BASE_FIRSTCONTACT_6_MD5='087d177826e2aea2dcafcec8bd9e3d68'
-ARCHIVE_BASE_FIRSTCONTACT_6_SIZE='1152'
-ARCHIVE_BASE_FIRSTCONTACT_6_VERSION='3.10.0.2-gog68987'
 
 ARCHIVE_BASE_FIRSTCONTACT_5_NAME='stellaris_first_contact_story_pack_3_9_3_68314.sh'
 ARCHIVE_BASE_FIRSTCONTACT_5_MD5='870a8a53a98f020d9cb55e2b962b6172'
