@@ -13,11 +13,12 @@ set -o errexit
 # - Overlord
 # - Galactic Paragons
 # - Astral Planes
+# - The Machine Age
 ###
 
-script_version=20240127.1
+script_version=20240620.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.29'
 
 GAME_ID='stellaris'
 GAME_NAME='Stellaris'
@@ -46,40 +47,43 @@ EXPANSION_NAME_PARAGONS='Galactic Paragons'
 EXPANSION_ID_PLANES='astral-planes'
 EXPANSION_NAME_PLANES='Astral Planes'
 
+EXPANSION_ID_MACHINE='the-machine-age'
+EXPANSION_NAME_MACHINE='The Machine Age'
+
 # Archives
 
 ## Utopia
 
+ARCHIVE_BASE_UTOPIA_54_NAME='stellaris_utopia_3_12_5_74193.sh'
+ARCHIVE_BASE_UTOPIA_54_MD5='94ce113fad5b52d0464bfa48905412cc'
+ARCHIVE_BASE_UTOPIA_54_SIZE='75007'
+ARCHIVE_BASE_UTOPIA_54_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_UTOPIA_54_URL='https://www.gog.com/game/stellaris_utopia'
+
+ARCHIVE_BASE_UTOPIA_53_NAME='stellaris_utopia_3_12_4_1_74025.sh'
+ARCHIVE_BASE_UTOPIA_53_MD5='96bfe0c26d3119ff5b82b9934e87164c'
+ARCHIVE_BASE_UTOPIA_53_SIZE='75007'
+ARCHIVE_BASE_UTOPIA_53_VERSION='3.12.4-gog74025'
+
+ARCHIVE_BASE_UTOPIA_52_NAME='stellaris_utopia_3_12_2_73401.sh'
+ARCHIVE_BASE_UTOPIA_52_MD5='4197f0b4e82a8af8267fc3f19e38c2de'
+ARCHIVE_BASE_UTOPIA_52_SIZE='75007'
+ARCHIVE_BASE_UTOPIA_52_VERSION='3.12.2-gog73401'
+
+ARCHIVE_BASE_UTOPIA_51_NAME='stellaris_utopia_3_12_1_73183.sh'
+ARCHIVE_BASE_UTOPIA_51_MD5='081f86c652cc1d32e10f1cabbc381aa8'
+ARCHIVE_BASE_UTOPIA_51_SIZE='75007'
+ARCHIVE_BASE_UTOPIA_51_VERSION='3.12.1-gog73183'
+
+ARCHIVE_BASE_UTOPIA_50_NAME='stellaris_utopia_3_11_3_0_72561.sh'
+ARCHIVE_BASE_UTOPIA_50_MD5='b459de0ff28f660f9f9f6a38b5963df8'
+ARCHIVE_BASE_UTOPIA_50_SIZE='75007'
+ARCHIVE_BASE_UTOPIA_50_VERSION='3.11.3-gog72561'
+
 ARCHIVE_BASE_UTOPIA_47_NAME='stellaris_utopia_3_10_4_70670.sh'
 ARCHIVE_BASE_UTOPIA_47_MD5='34740602274bd7cb248a25dbcf68ae50'
 ARCHIVE_BASE_UTOPIA_47_SIZE='75007'
 ARCHIVE_BASE_UTOPIA_47_VERSION='3.10.4-gog70670'
-ARCHIVE_BASE_UTOPIA_47_URL='https://www.gog.com/game/stellaris_utopia'
-
-ARCHIVE_BASE_UTOPIA_46_NAME='stellaris_utopia_3_10_4_69706.sh'
-ARCHIVE_BASE_UTOPIA_46_MD5='b941854d72b3941de2e9a2a5c0bd09f5'
-ARCHIVE_BASE_UTOPIA_46_SIZE='75007'
-ARCHIVE_BASE_UTOPIA_46_VERSION='3.10.4-gog69706'
-
-ARCHIVE_BASE_UTOPIA_45_NAME='stellaris_utopia_3_10_3_69539.sh'
-ARCHIVE_BASE_UTOPIA_45_MD5='28ad8fb133f7274e9094e68290c2bf4a'
-ARCHIVE_BASE_UTOPIA_45_SIZE='75328'
-ARCHIVE_BASE_UTOPIA_45_VERSION='3.10.3-gog69539'
-
-ARCHIVE_BASE_UTOPIA_44_NAME='stellaris_utopia_3_10_2_69346.sh'
-ARCHIVE_BASE_UTOPIA_44_MD5='de3da13d66cae59773672e8174b37ba6'
-ARCHIVE_BASE_UTOPIA_44_SIZE='75328'
-ARCHIVE_BASE_UTOPIA_44_VERSION='3.10.2-gog69346'
-
-ARCHIVE_BASE_UTOPIA_43_NAME='stellaris_utopia_3_10_1_69202.sh'
-ARCHIVE_BASE_UTOPIA_43_MD5='09cd47f044d34cfdde5ef304ac98275d'
-ARCHIVE_BASE_UTOPIA_43_SIZE='75324'
-ARCHIVE_BASE_UTOPIA_43_VERSION='3.10.1-gog69202'
-
-ARCHIVE_BASE_UTOPIA_42_NAME='stellaris_utopia_3_10_0_2_68987.sh'
-ARCHIVE_BASE_UTOPIA_42_MD5='56e133c664fa914c20470499c27d1151'
-ARCHIVE_BASE_UTOPIA_42_SIZE='75328'
-ARCHIVE_BASE_UTOPIA_42_VERSION='3.10.0.2-gog68987'
 
 ARCHIVE_BASE_UTOPIA_41_NAME='stellaris_utopia_3_9_3_68314.sh'
 ARCHIVE_BASE_UTOPIA_41_MD5='b720f9ac6deec5dda989e0b52c2cee80'
@@ -133,36 +137,36 @@ ARCHIVE_BASE_UTOPIA_17_VERSION='3.0.3-gog47193'
 
 ## Apocalypse
 
+ARCHIVE_BASE_APOCALYPSE_44_NAME='stellaris_apocalypse_3_12_5_74193.sh'
+ARCHIVE_BASE_APOCALYPSE_44_MD5='72c6721003d27d922fd134210da8b82f'
+ARCHIVE_BASE_APOCALYPSE_44_SIZE='37877'
+ARCHIVE_BASE_APOCALYPSE_44_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_APOCALYPSE_44_URL='https://www.gog.com/game/stellaris_apocalypse'
+
+ARCHIVE_BASE_APOCALYPSE_43_NAME='stellaris_apocalypse_3_12_4_1_74025.sh'
+ARCHIVE_BASE_APOCALYPSE_43_MD5='fc4ef87d5a954ad06b501ba8c80e6a08'
+ARCHIVE_BASE_APOCALYPSE_43_SIZE='37877'
+ARCHIVE_BASE_APOCALYPSE_43_VERSION='3.12.4-gog74025'
+
+ARCHIVE_BASE_APOCALYPSE_42_NAME='stellaris_apocalypse_3_12_2_73401.sh'
+ARCHIVE_BASE_APOCALYPSE_42_MD5='b83089a711119965ff6b29a12e77b39c'
+ARCHIVE_BASE_APOCALYPSE_42_SIZE='37877'
+ARCHIVE_BASE_APOCALYPSE_42_VERSION='3.12.2-gog73401'
+
+ARCHIVE_BASE_APOCALYPSE_41_NAME='stellaris_apocalypse_3_12_1_73183.sh'
+ARCHIVE_BASE_APOCALYPSE_41_MD5='de133d9b90807895f128f9ae3f4ccd1f'
+ARCHIVE_BASE_APOCALYPSE_41_SIZE='37877'
+ARCHIVE_BASE_APOCALYPSE_41_VERSION='3.12.1-gog73183'
+
+ARCHIVE_BASE_APOCALYPSE_40_NAME='stellaris_apocalypse_3_11_3_0_72561.sh'
+ARCHIVE_BASE_APOCALYPSE_40_MD5='5865125d875c8ddc549b8f0f4fd79ebd'
+ARCHIVE_BASE_APOCALYPSE_40_SIZE='37877'
+ARCHIVE_BASE_APOCALYPSE_40_VERSION='3.11.3-gog72561'
+
 ARCHIVE_BASE_APOCALYPSE_37_NAME='stellaris_apocalypse_3_10_4_70670.sh'
 ARCHIVE_BASE_APOCALYPSE_37_MD5='77856badbd6716a8d4b2b7c3d50dac7d'
 ARCHIVE_BASE_APOCALYPSE_37_SIZE='37877'
 ARCHIVE_BASE_APOCALYPSE_37_VERSION='3.10.4-gog70670'
-ARCHIVE_BASE_APOCALYPSE_37_URL='https://www.gog.com/game/stellaris_apocalypse'
-
-ARCHIVE_BASE_APOCALYPSE_36_NAME='stellaris_apocalypse_3_10_4_69706.sh'
-ARCHIVE_BASE_APOCALYPSE_36_MD5='b894170308363ea56cc7d74206c67219'
-ARCHIVE_BASE_APOCALYPSE_36_SIZE='37877'
-ARCHIVE_BASE_APOCALYPSE_36_VERSION='3.10.4-gog69706'
-
-ARCHIVE_BASE_APOCALYPSE_35_NAME='stellaris_apocalypse_3_10_3_69539.sh'
-ARCHIVE_BASE_APOCALYPSE_35_MD5='d4c87fe2168b68d31e4998933ed81d78'
-ARCHIVE_BASE_APOCALYPSE_35_SIZE='38196'
-ARCHIVE_BASE_APOCALYPSE_35_VERSION='3.10.3-gog69539'
-
-ARCHIVE_BASE_APOCALYPSE_34_NAME='stellaris_apocalypse_3_10_2_69346.sh'
-ARCHIVE_BASE_APOCALYPSE_34_MD5='c36eb19699cec1afa1b2fde53b49f3ca'
-ARCHIVE_BASE_APOCALYPSE_34_SIZE='38196'
-ARCHIVE_BASE_APOCALYPSE_34_VERSION='3.10.2-gog69346'
-
-ARCHIVE_BASE_APOCALYPSE_33_NAME='stellaris_apocalypse_3_10_1_69202.sh'
-ARCHIVE_BASE_APOCALYPSE_33_MD5='ac4266364748ada11f6119d659934617'
-ARCHIVE_BASE_APOCALYPSE_33_SIZE='38196'
-ARCHIVE_BASE_APOCALYPSE_33_VERSION='3.10.1-gog69202'
-
-ARCHIVE_BASE_APOCALYPSE_32_NAME='stellaris_apocalypse_3_10_0_2_68987.sh'
-ARCHIVE_BASE_APOCALYPSE_32_MD5='84b1b5c099f9a1ade045491ec1000dc3'
-ARCHIVE_BASE_APOCALYPSE_32_SIZE='38196'
-ARCHIVE_BASE_APOCALYPSE_32_VERSION='3.10.0.2-gog68987'
 
 ARCHIVE_BASE_APOCALYPSE_31_NAME='stellaris_apocalypse_3_9_3_68314.sh'
 ARCHIVE_BASE_APOCALYPSE_31_MD5='1e81c558321b0c494118f5eaa320a31a'
@@ -216,36 +220,36 @@ ARCHIVE_BASE_APOCALYPSE_7_VERSION='3.0.3-gog47193'
 
 ## MegaCorp
 
+ARCHIVE_BASE_MEGACORP_41_NAME='stellaris_megacorp_3_12_5_74193.sh'
+ARCHIVE_BASE_MEGACORP_41_MD5='056684f8cabd2bff919a6f1e1b12837a'
+ARCHIVE_BASE_MEGACORP_41_SIZE='130614'
+ARCHIVE_BASE_MEGACORP_41_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_MEGACORP_41_URL='https://www.gog.com/game/stellaris_megacorp'
+
+ARCHIVE_BASE_MEGACORP_40_NAME='stellaris_megacorp_3_12_4_1_74025.sh'
+ARCHIVE_BASE_MEGACORP_40_MD5='17ebb2f17a5ec3e50d21dcb1ac945c25'
+ARCHIVE_BASE_MEGACORP_40_SIZE='130614'
+ARCHIVE_BASE_MEGACORP_40_VERSION='3.12.4-gog74025'
+
+ARCHIVE_BASE_MEGACORP_39_NAME='stellaris_megacorp_3_12_2_73401.sh'
+ARCHIVE_BASE_MEGACORP_39_MD5='6cebe3f755bfa8fd74f4e9941149875f'
+ARCHIVE_BASE_MEGACORP_39_SIZE='130614'
+ARCHIVE_BASE_MEGACORP_39_VERSION='3.12.2-gog73401'
+
+ARCHIVE_BASE_MEGACORP_38_NAME='stellaris_megacorp_3_12_1_73183.sh'
+ARCHIVE_BASE_MEGACORP_38_MD5='1521312d5bbd3097c9d107e3ecdf656e'
+ARCHIVE_BASE_MEGACORP_38_SIZE='130614'
+ARCHIVE_BASE_MEGACORP_38_VERSION='3.12.1-gog73183'
+
+ARCHIVE_BASE_MEGACORP_37_NAME='stellaris_megacorp_3_11_3_0_72561.sh'
+ARCHIVE_BASE_MEGACORP_37_MD5='9c9fda0324405590e48d4da9741dcdb0'
+ARCHIVE_BASE_MEGACORP_37_SIZE='130614'
+ARCHIVE_BASE_MEGACORP_37_VERSION='3.11.3-gog72561'
+
 ARCHIVE_BASE_MEGACORP_34_NAME='stellaris_megacorp_3_10_4_70670.sh'
 ARCHIVE_BASE_MEGACORP_34_MD5='c155eb5f1b6f3283e068b17574107070'
 ARCHIVE_BASE_MEGACORP_34_SIZE='130614'
 ARCHIVE_BASE_MEGACORP_34_VERSION='3.10.4-gog70670'
-ARCHIVE_BASE_MEGACORP_34_URL='https://www.gog.com/game/stellaris_megacorp'
-
-ARCHIVE_BASE_MEGACORP_33_NAME='stellaris_megacorp_3_10_4_69706.sh'
-ARCHIVE_BASE_MEGACORP_33_MD5='4485e8c66c997bec73f95fb6e7aba992'
-ARCHIVE_BASE_MEGACORP_33_SIZE='130614'
-ARCHIVE_BASE_MEGACORP_33_VERSION='3.10.4-gog69706'
-
-ARCHIVE_BASE_MEGACORP_32_NAME='stellaris_megacorp_3_10_3_69539.sh'
-ARCHIVE_BASE_MEGACORP_32_MD5='df9e76d2d210bae53fde19e7e88742eb'
-ARCHIVE_BASE_MEGACORP_32_SIZE='130940'
-ARCHIVE_BASE_MEGACORP_32_VERSION='3.10.3-gog69539'
-
-ARCHIVE_BASE_MEGACORP_31_NAME='stellaris_megacorp_3_10_2_69346.sh'
-ARCHIVE_BASE_MEGACORP_31_MD5='521df86e0279c09dac4be008f0f40dbb'
-ARCHIVE_BASE_MEGACORP_31_SIZE='130940'
-ARCHIVE_BASE_MEGACORP_31_VERSION='3.10.2-gog69346'
-
-ARCHIVE_BASE_MEGACORP_30_NAME='stellaris_megacorp_3_10_1_69202.sh'
-ARCHIVE_BASE_MEGACORP_30_MD5='c1f6bdde4832e94df24d75e7ae2a5383'
-ARCHIVE_BASE_MEGACORP_30_SIZE='130940'
-ARCHIVE_BASE_MEGACORP_30_VERSION='3.10.1-gog69202'
-
-ARCHIVE_BASE_MEGACORP_29_NAME='stellaris_megacorp_3_10_0_2_68987.sh'
-ARCHIVE_BASE_MEGACORP_29_MD5='55f0cfa082c93e363c44d2edabc3f881'
-ARCHIVE_BASE_MEGACORP_29_SIZE='130940'
-ARCHIVE_BASE_MEGACORP_29_VERSION='3.10.0.2-gog68987'
 
 ARCHIVE_BASE_MEGACORP_28_NAME='stellaris_megacorp_3_9_3_68314.sh'
 ARCHIVE_BASE_MEGACORP_28_MD5='b4bf123675295aa81910698500cdd33b'
@@ -299,36 +303,36 @@ ARCHIVE_BASE_MEGACORP_4_VERSION='3.0.3-gog47193'
 
 ## Federations
 
+ARCHIVE_BASE_FEDERATIONS_36_NAME='stellaris_federations_3_12_5_74193.sh'
+ARCHIVE_BASE_FEDERATIONS_36_MD5='77b14499ea1a8fe7d643e3881a473d0d'
+ARCHIVE_BASE_FEDERATIONS_36_SIZE='14433'
+ARCHIVE_BASE_FEDERATIONS_36_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_FEDERATIONS_36_URL='https://www.gog.com/game/stellaris_federations'
+
+ARCHIVE_BASE_FEDERATIONS_35_NAME='stellaris_federations_3_12_4_1_74025.sh'
+ARCHIVE_BASE_FEDERATIONS_35_MD5='139d67b3847f35ca14b86bb035c7e1d7'
+ARCHIVE_BASE_FEDERATIONS_35_SIZE='14433'
+ARCHIVE_BASE_FEDERATIONS_35_VERSION='3.12.4-gog74025'
+
+ARCHIVE_BASE_FEDERATIONS_34_NAME='stellaris_federations_3_12_2_73401.sh'
+ARCHIVE_BASE_FEDERATIONS_34_MD5='d91b8fba53cf45f1b43a82d9536756a4'
+ARCHIVE_BASE_FEDERATIONS_34_SIZE='14433'
+ARCHIVE_BASE_FEDERATIONS_34_VERSION='3.12.2-gog73401'
+
+ARCHIVE_BASE_FEDERATIONS_33_NAME='stellaris_federations_3_12_1_73183.sh'
+ARCHIVE_BASE_FEDERATIONS_33_MD5='7e73dee5ac683a0f1862c6e775d3a8b3'
+ARCHIVE_BASE_FEDERATIONS_33_SIZE='14433'
+ARCHIVE_BASE_FEDERATIONS_33_VERSION='3.12.1-gog73183'
+
+ARCHIVE_BASE_FEDERATIONS_32_NAME='stellaris_federations_3_11_3_0_72561.sh'
+ARCHIVE_BASE_FEDERATIONS_32_MD5='de18cbab731d65f25fcc58ea98a16a12'
+ARCHIVE_BASE_FEDERATIONS_32_SIZE='14433'
+ARCHIVE_BASE_FEDERATIONS_32_VERSION='3.11.3-gog72561'
+
 ARCHIVE_BASE_FEDERATIONS_29_NAME='stellaris_federations_3_10_4_70670.sh'
 ARCHIVE_BASE_FEDERATIONS_29_MD5='00836b70d3d84d95de238c607e25e309'
 ARCHIVE_BASE_FEDERATIONS_29_SIZE='14433'
 ARCHIVE_BASE_FEDERATIONS_29_VERSION='3.10.4-gog70670'
-ARCHIVE_BASE_FEDERATIONS_29_URL='https://www.gog.com/game/stellaris_federations'
-
-ARCHIVE_BASE_FEDERATIONS_28_NAME='stellaris_federations_3_10_4_69706.sh'
-ARCHIVE_BASE_FEDERATIONS_28_MD5='8afa570b56dd696db6ac7dd3d8d812ae'
-ARCHIVE_BASE_FEDERATIONS_28_SIZE='14433'
-ARCHIVE_BASE_FEDERATIONS_28_VERSION='3.10.4-gog69706'
-
-ARCHIVE_BASE_FEDERATIONS_27_NAME='stellaris_federations_3_10_3_69539.sh'
-ARCHIVE_BASE_FEDERATIONS_27_MD5='2f602f1a59f8850357773de50d58b531'
-ARCHIVE_BASE_FEDERATIONS_27_SIZE='14752'
-ARCHIVE_BASE_FEDERATIONS_27_VERSION='3.10.3-gog69539'
-
-ARCHIVE_BASE_FEDERATIONS_26_NAME='stellaris_federations_3_10_2_69346.sh'
-ARCHIVE_BASE_FEDERATIONS_26_MD5='6093bfd50439b9d548504cfb035405c2'
-ARCHIVE_BASE_FEDERATIONS_26_SIZE='14752'
-ARCHIVE_BASE_FEDERATIONS_26_VERSION='3.10.2-gog69346'
-
-ARCHIVE_BASE_FEDERATIONS_25_NAME='stellaris_federations_3_10_1_69202.sh'
-ARCHIVE_BASE_FEDERATIONS_25_MD5='2597c00c7e2e775c05a11c3b695d5db3'
-ARCHIVE_BASE_FEDERATIONS_25_SIZE='14752'
-ARCHIVE_BASE_FEDERATIONS_25_VERSION='3.10.1-gog69202'
-
-ARCHIVE_BASE_FEDERATIONS_24_NAME='stellaris_federations_3_10_0_2_68987.sh'
-ARCHIVE_BASE_FEDERATIONS_24_MD5='1cb0a687189ef805856709e9f8c8e0ad'
-ARCHIVE_BASE_FEDERATIONS_24_SIZE='14752'
-ARCHIVE_BASE_FEDERATIONS_24_VERSION='3.10.0.2-gog68987'
 
 ARCHIVE_BASE_FEDERATIONS_23_NAME='stellaris_federations_3_9_3_68314.sh'
 ARCHIVE_BASE_FEDERATIONS_23_MD5='5c2ecccea91eeeea578cd2925a5621eb'
@@ -372,36 +376,36 @@ ARCHIVE_BASE_FEDERATIONS_1_VERSION='3.2.2-gog51685'
 
 ## Nemesis
 
+ARCHIVE_BASE_NEMESIS_23_NAME='stellaris_nemesis_3_12_5_74193.sh'
+ARCHIVE_BASE_NEMESIS_23_MD5='30187118ff7f8fed4db3b453f2b1a467'
+ARCHIVE_BASE_NEMESIS_23_SIZE='38539'
+ARCHIVE_BASE_NEMESIS_23_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_NEMESIS_23_URL='https://www.gog.com/game/stellaris_nemesis'
+
+ARCHIVE_BASE_NEMESIS_22_NAME='stellaris_nemesis_3_12_4_1_74025.sh'
+ARCHIVE_BASE_NEMESIS_22_MD5='c4cf716d5ba5aa6a4b508cc7cdaa6404'
+ARCHIVE_BASE_NEMESIS_22_SIZE='38539'
+ARCHIVE_BASE_NEMESIS_22_VERSION='3.12.4-gog74025'
+
+ARCHIVE_BASE_NEMESIS_21_NAME='stellaris_nemesis_3_12_2_73401.sh'
+ARCHIVE_BASE_NEMESIS_21_MD5='b820e1b7dde6e5e210f5adbd25406ac4'
+ARCHIVE_BASE_NEMESIS_21_SIZE='38539'
+ARCHIVE_BASE_NEMESIS_21_VERSION='3.12.2-gog73401'
+
+ARCHIVE_BASE_NEMESIS_20_NAME='stellaris_nemesis_3_12_1_73183.sh'
+ARCHIVE_BASE_NEMESIS_20_MD5='32c943bc6f3cdd266135c1a7c7479e83'
+ARCHIVE_BASE_NEMESIS_20_SIZE='38539'
+ARCHIVE_BASE_NEMESIS_20_VERSION='3.12.1-gog73183'
+
+ARCHIVE_BASE_NEMESIS_19_NAME='stellaris_nemesis_3_11_3_0_72561.sh'
+ARCHIVE_BASE_NEMESIS_19_MD5='a6380543924bf1479101511337238f29'
+ARCHIVE_BASE_NEMESIS_19_SIZE='38539'
+ARCHIVE_BASE_NEMESIS_19_VERSION='3.11.3-gog72561'
+
 ARCHIVE_BASE_NEMESIS_16_NAME='stellaris_nemesis_3_10_4_70670.sh'
 ARCHIVE_BASE_NEMESIS_16_MD5='749b70150b8b77b9f905d50b641594c7'
 ARCHIVE_BASE_NEMESIS_16_SIZE='38539'
 ARCHIVE_BASE_NEMESIS_16_VERSION='3.10.4-gog70670'
-ARCHIVE_BASE_NEMESIS_16_URL='https://www.gog.com/game/stellaris_nemesis'
-
-ARCHIVE_BASE_NEMESIS_15_NAME='stellaris_nemesis_3_10_4_69706.sh'
-ARCHIVE_BASE_NEMESIS_15_MD5='312e8472b38288a83d3adf590794e299'
-ARCHIVE_BASE_NEMESIS_15_SIZE='38539'
-ARCHIVE_BASE_NEMESIS_15_VERSION='3.10.4-gog69706'
-
-ARCHIVE_BASE_NEMESIS_14_NAME='stellaris_nemesis_3_10_3_69539.sh'
-ARCHIVE_BASE_NEMESIS_14_MD5='372e8d3daaeb61abed3c61b321faa29a'
-ARCHIVE_BASE_NEMESIS_14_SIZE='38856'
-ARCHIVE_BASE_NEMESIS_14_VERSION='3.10.3-gog69539'
-
-ARCHIVE_BASE_NEMESIS_13_NAME='stellaris_nemesis_3_10_2_69346.sh'
-ARCHIVE_BASE_NEMESIS_13_MD5='7ea2f1b47be86b5ba0c756f9c708f5d0'
-ARCHIVE_BASE_NEMESIS_13_SIZE='38856'
-ARCHIVE_BASE_NEMESIS_13_VERSION='3.10.2-gog69346'
-
-ARCHIVE_BASE_NEMESIS_12_NAME='stellaris_nemesis_3_10_1_69202.sh'
-ARCHIVE_BASE_NEMESIS_12_MD5='a947e9923334ef68652edbb24191e20c'
-ARCHIVE_BASE_NEMESIS_12_SIZE='38856'
-ARCHIVE_BASE_NEMESIS_12_VERSION='3.10.1-gog69202'
-
-ARCHIVE_BASE_NEMESIS_11_NAME='stellaris_nemesis_3_10_0_2_68987.sh'
-ARCHIVE_BASE_NEMESIS_11_MD5='83964f37d25affd9132d6e49baf6d76b'
-ARCHIVE_BASE_NEMESIS_11_SIZE='38856'
-ARCHIVE_BASE_NEMESIS_11_VERSION='3.10.0.2-gog68987'
 
 ARCHIVE_BASE_NEMESIS_10_NAME='stellaris_nemesis_3_9_3_68314.sh'
 ARCHIVE_BASE_NEMESIS_10_MD5='105f2c56365c3b2b3c329806e4b5272b'
@@ -425,36 +429,36 @@ ARCHIVE_BASE_NEMESIS_0_VERSION='3.6.1-gog60754'
 
 ## Overlord
 
+ARCHIVE_BASE_OVERLORD_18_NAME='stellaris_overlord_3_12_5_74193.sh'
+ARCHIVE_BASE_OVERLORD_18_MD5='62f8f8bf6a5f9774bd1fb036d73e2843'
+ARCHIVE_BASE_OVERLORD_18_SIZE='99860'
+ARCHIVE_BASE_OVERLORD_18_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_OVERLORD_18_URL='https://www.gog.com/game/stellaris_overlord'
+
+ARCHIVE_BASE_OVERLORD_17_NAME='stellaris_overlord_3_12_4_1_74025.sh'
+ARCHIVE_BASE_OVERLORD_17_MD5='564f44f5d624199fe16f95eed29c0f13'
+ARCHIVE_BASE_OVERLORD_17_SIZE='99860'
+ARCHIVE_BASE_OVERLORD_17_VERSION='3.12.4-gog74025'
+
+ARCHIVE_BASE_OVERLORD_16_NAME='stellaris_overlord_3_12_2_73401.sh'
+ARCHIVE_BASE_OVERLORD_16_MD5='a9ecb4c919b3427cea15408d87bc1e55'
+ARCHIVE_BASE_OVERLORD_16_SIZE='99860'
+ARCHIVE_BASE_OVERLORD_16_VERSION='3.12.2-gog73401'
+
+ARCHIVE_BASE_OVERLORD_15_NAME='stellaris_overlord_3_12_1_73183.sh'
+ARCHIVE_BASE_OVERLORD_15_MD5='05da07a47a13cb9d937c9d175e589416'
+ARCHIVE_BASE_OVERLORD_15_SIZE='99860'
+ARCHIVE_BASE_OVERLORD_15_VERSION='3.12.1-gog73183'
+
+ARCHIVE_BASE_OVERLORD_14_NAME='stellaris_overlord_3_11_3_0_72561.sh'
+ARCHIVE_BASE_OVERLORD_14_MD5='dd8189cd8134fc866c374864d0700b83'
+ARCHIVE_BASE_OVERLORD_14_SIZE='99860'
+ARCHIVE_BASE_OVERLORD_14_VERSION='3.11.3-gog72561'
+
 ARCHIVE_BASE_OVERLORD_11_NAME='stellaris_overlord_3_10_4_70670.sh'
 ARCHIVE_BASE_OVERLORD_11_MD5='a6bf968c0f6c7dc75998884b333025ec'
 ARCHIVE_BASE_OVERLORD_11_SIZE='99860'
 ARCHIVE_BASE_OVERLORD_11_VERSION='3.10.4-gog70670'
-ARCHIVE_BASE_OVERLORD_11_URL='https://www.gog.com/game/stellaris_overlord'
-
-ARCHIVE_BASE_OVERLORD_10_NAME='stellaris_overlord_3_10_4_69706.sh'
-ARCHIVE_BASE_OVERLORD_10_MD5='927949921df505f021d33780b53a5418'
-ARCHIVE_BASE_OVERLORD_10_SIZE='99860'
-ARCHIVE_BASE_OVERLORD_10_VERSION='3.10.4-gog69706'
-
-ARCHIVE_BASE_OVERLORD_9_NAME='stellaris_overlord_3_10_3_69539.sh'
-ARCHIVE_BASE_OVERLORD_9_MD5='170a93d40a6d2cd1986e2fbaf4272735'
-ARCHIVE_BASE_OVERLORD_9_SIZE='100180'
-ARCHIVE_BASE_OVERLORD_9_VERSION='3.10.3-gog69539'
-
-ARCHIVE_BASE_OVERLORD_8_NAME='stellaris_overlord_3_10_2_69346.sh'
-ARCHIVE_BASE_OVERLORD_8_MD5='28b8de70c9c213e38c04b00edf0db0b1'
-ARCHIVE_BASE_OVERLORD_8_SIZE='100184'
-ARCHIVE_BASE_OVERLORD_8_VERSION='3.10.2-gog69346'
-
-ARCHIVE_BASE_OVERLORD_7_NAME='stellaris_overlord_3_10_1_69202.sh'
-ARCHIVE_BASE_OVERLORD_7_MD5='ae491975383cfcfc35da0b1b4e003cc0'
-ARCHIVE_BASE_OVERLORD_7_SIZE='100180'
-ARCHIVE_BASE_OVERLORD_7_VERSION='3.10.1-gog69202'
-
-ARCHIVE_BASE_OVERLORD_6_NAME='stellaris_overlord_3_10_0_2_68987.sh'
-ARCHIVE_BASE_OVERLORD_6_MD5='031c07da495842109040c6449a2b4db4'
-ARCHIVE_BASE_OVERLORD_6_SIZE='100184'
-ARCHIVE_BASE_OVERLORD_6_VERSION='3.10.0.2-gog68987'
 
 ARCHIVE_BASE_OVERLORD_5_NAME='stellaris_overlord_3_9_3_68314.sh'
 ARCHIVE_BASE_OVERLORD_5_MD5='580bcbdf375ead938c80956f27e1069d'
@@ -468,36 +472,36 @@ ARCHIVE_BASE_OVERLORD_2_VERSION='3.8.4.1-gog65337'
 
 ## Galactic Paragons
 
+ARCHIVE_BASE_PARAGONS_18_NAME='stellaris_galactic_paragons_3_12_5_74193.sh'
+ARCHIVE_BASE_PARAGONS_18_MD5='00b9ebf125e6812ccd02840db3f7bcd7'
+ARCHIVE_BASE_PARAGONS_18_SIZE='832'
+ARCHIVE_BASE_PARAGONS_18_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_PARAGONS_18_URL='https://www.gog.com/game/stellaris_galactic_paragons'
+
+ARCHIVE_BASE_PARAGONS_17_NAME='stellaris_galactic_paragons_3_12_4_1_74025.sh'
+ARCHIVE_BASE_PARAGONS_17_MD5='c6344de2edf30bb6318347691fe2f762'
+ARCHIVE_BASE_PARAGONS_17_SIZE='832'
+ARCHIVE_BASE_PARAGONS_17_VERSION='3.12.4-gog74025'
+
+ARCHIVE_BASE_PARAGONS_16_NAME='stellaris_galactic_paragons_3_12_2_73401.sh'
+ARCHIVE_BASE_PARAGONS_16_MD5='45f99ab73623db6cce5923efa2923706'
+ARCHIVE_BASE_PARAGONS_16_SIZE='832'
+ARCHIVE_BASE_PARAGONS_16_VERSION='3.12.2-gog73401'
+
+ARCHIVE_BASE_PARAGONS_15_NAME='stellaris_galactic_paragons_3_12_1_73183.sh'
+ARCHIVE_BASE_PARAGONS_15_MD5='321f865bacc45ccde7a44b91b21ead42'
+ARCHIVE_BASE_PARAGONS_15_SIZE='832'
+ARCHIVE_BASE_PARAGONS_15_VERSION='3.12.1-gog73183'
+
+ARCHIVE_BASE_PARAGONS_14_NAME='stellaris_galactic_paragons_3_11_3_0_72561.sh'
+ARCHIVE_BASE_PARAGONS_14_MD5='ee6878f407ab24721974463a3c957d68'
+ARCHIVE_BASE_PARAGONS_14_SIZE='832'
+ARCHIVE_BASE_PARAGONS_14_VERSION='3.11.3-gog72561'
+
 ARCHIVE_BASE_PARAGONS_11_NAME='stellaris_galactic_paragons_3_10_4_70670.sh'
 ARCHIVE_BASE_PARAGONS_11_MD5='e081e220e0a862bd8adc42860b9bd1f4'
 ARCHIVE_BASE_PARAGONS_11_SIZE='832'
 ARCHIVE_BASE_PARAGONS_11_VERSION='3.10.4-gog70670'
-ARCHIVE_BASE_PARAGONS_11_URL='https://www.gog.com/game/stellaris_galactic_paragons'
-
-ARCHIVE_BASE_PARAGONS_10_NAME='stellaris_galactic_paragons_3_10_4_69706.sh'
-ARCHIVE_BASE_PARAGONS_10_MD5='0781905dcf4cf726b21574c74b018a94'
-ARCHIVE_BASE_PARAGONS_10_SIZE='832'
-ARCHIVE_BASE_PARAGONS_10_VERSION='3.10.4-gog69706'
-
-ARCHIVE_BASE_PARAGONS_9_NAME='stellaris_galactic_paragons_3_10_3_69539.sh'
-ARCHIVE_BASE_PARAGONS_9_MD5='a2d47fb32fbdfdaad4015aac868f0729'
-ARCHIVE_BASE_PARAGONS_9_SIZE='1152'
-ARCHIVE_BASE_PARAGONS_9_VERSION='3.10.3-gog69539'
-
-ARCHIVE_BASE_PARAGONS_8_NAME='stellaris_galactic_paragons_3_10_2_69346.sh'
-ARCHIVE_BASE_PARAGONS_8_MD5='4338b6764e1c76d2d08838c4b940698b'
-ARCHIVE_BASE_PARAGONS_8_SIZE='1152'
-ARCHIVE_BASE_PARAGONS_8_VERSION='3.10.2-gog69346'
-
-ARCHIVE_BASE_PARAGONS_7_NAME='stellaris_galactic_paragons_3_10_1_69202.sh'
-ARCHIVE_BASE_PARAGONS_7_MD5='a51b35147b8737a83dc2c87d1e15c6e7'
-ARCHIVE_BASE_PARAGONS_7_SIZE='1152'
-ARCHIVE_BASE_PARAGONS_7_VERSION='3.10.1-gog69202'
-
-ARCHIVE_BASE_PARAGONS_6_NAME='stellaris_galactic_paragons_3_10_0_2_68987.sh'
-ARCHIVE_BASE_PARAGONS_6_MD5='0a9ca705958130bf0472b47e91506afb'
-ARCHIVE_BASE_PARAGONS_6_SIZE='1152'
-ARCHIVE_BASE_PARAGONS_6_VERSION='3.10.0.2-gog68987'
 
 ARCHIVE_BASE_PARAGONS_5_NAME='stellaris_galactic_paragons_3_9_3_68314.sh'
 ARCHIVE_BASE_PARAGONS_5_MD5='4e1ad6ceb7a5e3bb6d55d1bc7547954e'
@@ -511,36 +515,59 @@ ARCHIVE_BASE_PARAGONS_2_VERSION='3.8.4.1-gog65337'
 
 ## Astral Planes
 
+ARCHIVE_BASE_PLANES_12_NAME='stellaris_astral_planes_3_12_5_74193.sh'
+ARCHIVE_BASE_PLANES_12_MD5='8cbaaaa68306cc90effacd2510cbe089'
+ARCHIVE_BASE_PLANES_12_SIZE='46789'
+ARCHIVE_BASE_PLANES_12_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_PLANES_12_URL='https://www.gog.com/game/stellaris_astral_planes'
+
+ARCHIVE_BASE_PLANES_11_NAME='stellaris_astral_planes_3_12_4_1_74025.sh'
+ARCHIVE_BASE_PLANES_11_MD5='1a7e9e9209d740c9a53aede66dcbc6c4'
+ARCHIVE_BASE_PLANES_11_SIZE='46789'
+ARCHIVE_BASE_PLANES_11_VERSION='3.12.4-gog74025'
+
+ARCHIVE_BASE_PLANES_10_NAME='stellaris_astral_planes_3_12_2_73401.sh'
+ARCHIVE_BASE_PLANES_10_MD5='c56ae7693d57798e6165d822c568a648'
+ARCHIVE_BASE_PLANES_10_SIZE='46789'
+ARCHIVE_BASE_PLANES_10_VERSION='3.12.2-gog73401'
+
+ARCHIVE_BASE_PLANES_9_NAME='stellaris_astral_planes_3_12_1_73183.sh'
+ARCHIVE_BASE_PLANES_9_MD5='ac2897874c86f0ca6f22c3c09f321c8e'
+ARCHIVE_BASE_PLANES_9_SIZE='46789'
+ARCHIVE_BASE_PLANES_9_VERSION='3.12.1-gog73183'
+
+ARCHIVE_BASE_PLANES_8_NAME='stellaris_astral_planes_3_11_3_0_72561.sh'
+ARCHIVE_BASE_PLANES_8_MD5='7d43cac5e6dd18238fff6f06b82be7c1'
+ARCHIVE_BASE_PLANES_8_SIZE='46789'
+ARCHIVE_BASE_PLANES_8_VERSION='3.11.3-gog72561'
+
 ARCHIVE_BASE_PLANES_5_NAME='stellaris_astral_planes_3_10_4_70670.sh'
 ARCHIVE_BASE_PLANES_5_MD5='fab105e52dffbf0ec425d4cedf89feae'
 ARCHIVE_BASE_PLANES_5_SIZE='46789'
 ARCHIVE_BASE_PLANES_5_VERSION='3.10.4-gog70670'
-ARCHIVE_BASE_PLANES_5_URL='https://www.gog.com/game/stellaris_astral_planes'
 
-ARCHIVE_BASE_PLANES_4_NAME='stellaris_astral_planes_3_10_4_69706.sh'
-ARCHIVE_BASE_PLANES_4_MD5='1f13892554e3dd7f518e6c24c7588902'
-ARCHIVE_BASE_PLANES_4_SIZE='46789'
-ARCHIVE_BASE_PLANES_4_VERSION='3.10.4-gog69706'
+## The Machine Age
 
-ARCHIVE_BASE_PLANES_3_NAME='stellaris_astral_planes_3_10_3_69539.sh'
-ARCHIVE_BASE_PLANES_3_MD5='fa20993e9d31c987a11a32a05a10fca3'
-ARCHIVE_BASE_PLANES_3_SIZE='47108'
-ARCHIVE_BASE_PLANES_3_VERSION='3.10.3-gog69539'
+ARCHIVE_BASE_MACHINE_3_NAME='stellaris_the_machine_age_3_12_5_74193.sh'
+ARCHIVE_BASE_MACHINE_3_MD5='06614dbbb8a94b20449f6a3a6f863347'
+ARCHIVE_BASE_MACHINE_3_SIZE='118726'
+ARCHIVE_BASE_MACHINE_3_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_MACHINE_3_URL='https://www.gog.com/game/stellaris_the_machine_age'
 
-ARCHIVE_BASE_PLANES_2_NAME='stellaris_astral_planes_3_10_2_69346.sh'
-ARCHIVE_BASE_PLANES_2_MD5='ccf3ead407701f817a64b35c5bf86e68'
-ARCHIVE_BASE_PLANES_2_SIZE='47108'
-ARCHIVE_BASE_PLANES_2_VERSION='3.10.2-gog69346'
+ARCHIVE_BASE_MACHINE_2_NAME='stellaris_the_machine_age_3_12_4_1_74025.sh'
+ARCHIVE_BASE_MACHINE_2_MD5='b6a0b8fff344a7454f28321f5c135ea1'
+ARCHIVE_BASE_MACHINE_2_SIZE='118726'
+ARCHIVE_BASE_MACHINE_2_VERSION='3.12.4-gog74025'
 
-ARCHIVE_BASE_PLANES_1_NAME='stellaris_astral_planes_3_10_1_69202.sh'
-ARCHIVE_BASE_PLANES_1_MD5='9c1e948d507f71c367502ad0b27b8556'
-ARCHIVE_BASE_PLANES_1_SIZE='47104'
-ARCHIVE_BASE_PLANES_1_VERSION='3.10.1-gog69202'
+ARCHIVE_BASE_MACHINE_1_NAME='stellaris_the_machine_age_3_12_2_73401.sh'
+ARCHIVE_BASE_MACHINE_1_MD5='9ddc20ef2c06daac40bffeaf838c1f3b'
+ARCHIVE_BASE_MACHINE_1_SIZE='118726'
+ARCHIVE_BASE_MACHINE_1_VERSION='3.12.2-gog73401'
 
-ARCHIVE_BASE_PLANES_0_NAME='stellaris_astral_planes_3_10_0_2_68987.sh'
-ARCHIVE_BASE_PLANES_0_MD5='02a08ebe68c3394d121724e3d7f2221c'
-ARCHIVE_BASE_PLANES_0_SIZE='47104'
-ARCHIVE_BASE_PLANES_0_VERSION='3.10.0.2-gog68987'
+ARCHIVE_BASE_MACHINE_0_NAME='stellaris_the_machine_age_3_12_1_73183.sh'
+ARCHIVE_BASE_MACHINE_0_MD5='7f56b69dd740fadc6a640b6e2a135e0a'
+ARCHIVE_BASE_MACHINE_0_SIZE='118726'
+ARCHIVE_BASE_MACHINE_0_VERSION='3.12.1-gog73183'
 
 
 CONTENT_PATH_DEFAULT='data/noarch/game'
