@@ -7,43 +7,43 @@ set -o errexit
 # Stellaris
 ###
 
-script_version=20240127.1
+script_version=20240620.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.27'
+PLAYIT_COMPATIBILITY_LEVEL='2.29'
 
 GAME_ID='stellaris'
 GAME_NAME='Stellaris'
 
+ARCHIVE_BASE_55_NAME='stellaris_3_12_5_74193.sh'
+ARCHIVE_BASE_55_MD5='bb1b18f25732a09a6f257554a1d98375'
+ARCHIVE_BASE_55_SIZE='18792782'
+ARCHIVE_BASE_55_VERSION='3.12.5-gog74193'
+ARCHIVE_BASE_55_URL='https://www.gog.com/game/stellaris'
+
+ARCHIVE_BASE_54_NAME='stellaris_3_12_4_1_74025.sh'
+ARCHIVE_BASE_54_MD5='1e8b5cf1ed842230893beec4794ada09'
+ARCHIVE_BASE_54_SIZE='18917681'
+ARCHIVE_BASE_54_VERSION='3.12.4-gog74025'
+
+ARCHIVE_BASE_53_NAME='stellaris_3_12_2_73401.sh'
+ARCHIVE_BASE_53_MD5='7e58c45097f67a90eb6a877c1c6068c5'
+ARCHIVE_BASE_53_SIZE='18775413'
+ARCHIVE_BASE_53_VERSION='3.12.2-gog73401'
+
+ARCHIVE_BASE_52_NAME='stellaris_3_12_1_73183.sh'
+ARCHIVE_BASE_52_MD5='063a3f3b021dd095ac80c4e832dc9c9f'
+ARCHIVE_BASE_52_SIZE='18860653'
+ARCHIVE_BASE_52_VERSION='3.12.1-gog73183'
+
+ARCHIVE_BASE_51_NAME='stellaris_3_11_3_0_72561.sh'
+ARCHIVE_BASE_51_MD5='a03584bd08d67544607fade70c8cb157'
+ARCHIVE_BASE_51_SIZE='16450506'
+ARCHIVE_BASE_51_VERSION='3.11.3-gog72561'
+
 ARCHIVE_BASE_48_NAME='stellaris_3_10_4_70670.sh'
 ARCHIVE_BASE_48_MD5='8703e439a2588f88987ad7d600674714'
 ARCHIVE_BASE_48_SIZE='16449439'
 ARCHIVE_BASE_48_VERSION='3.10.4-gog70670'
-ARCHIVE_BASE_48_URL='https://www.gog.com/game/stellaris'
-
-ARCHIVE_BASE_47_NAME='stellaris_3_10_4_69706.sh'
-ARCHIVE_BASE_47_MD5='d4fcec0db7928f942dc19debadf4f8b2'
-ARCHIVE_BASE_47_SIZE='16449439'
-ARCHIVE_BASE_47_VERSION='3.10.4-gog69706'
-
-ARCHIVE_BASE_46_NAME='stellaris_3_10_3_69539.sh'
-ARCHIVE_BASE_46_MD5='67b91bc3f3fb0a8f81d03a9f4020f5e4'
-ARCHIVE_BASE_46_SIZE='16517672'
-ARCHIVE_BASE_46_VERSION='3.10.3-gog69539'
-
-ARCHIVE_BASE_45_NAME='stellaris_3_10_2_69346.sh'
-ARCHIVE_BASE_45_MD5='809f5f041d4bc26e611e866a64298716'
-ARCHIVE_BASE_45_SIZE='16517672'
-ARCHIVE_BASE_45_VERSION='3.10.2-gog69346'
-
-ARCHIVE_BASE_44_NAME='stellaris_3_10_1_69202.sh'
-ARCHIVE_BASE_44_MD5='41a176a24fef76f1c1ce7fe0d9f09557'
-ARCHIVE_BASE_44_SIZE='16517656'
-ARCHIVE_BASE_44_VERSION='3.10.1-gog69202'
-
-ARCHIVE_BASE_43_NAME='stellaris_3_10_0_2_68987.sh'
-ARCHIVE_BASE_43_MD5='3c5f2869b1183d8cf9b72de5b99485cd'
-ARCHIVE_BASE_43_SIZE='16517564'
-ARCHIVE_BASE_43_VERSION='3.10.0.2-gog68987'
 
 ARCHIVE_BASE_42_NAME='stellaris_3_9_3_68314.sh'
 ARCHIVE_BASE_42_MD5='fb96d68d043643b032328023c09bbb53'
@@ -100,13 +100,18 @@ CONTENT_LIBS_BIN_FILES='
 libnakama-cpp.so
 libpops_api.so'
 CONTENT_GAME_BIN_FILES='
-stellaris
-*.py'
+crash_reporter
+tools
+stellaris'
+CONTENT_GAME_DATA_MODELS_SHIPS_FILES='
+gfx/models/ships'
 CONTENT_GAME_DATA_MODELS_FILES='
 gfx/models'
 CONTENT_GAME_DATA_FILES='
 common
+curated_save_games
 dlc
+dlc_metadata
 events
 flags
 fonts
@@ -122,7 +127,11 @@ prescripted_countries
 previewer_assets
 sound
 tweakergui_assets
-*.txt'
+unchecked_defines
+ChangeLog.txt
+ChangeLogBlank.txt
+checksum_manifest.txt
+ThirdPartyLicenses.txt'
 
 ## TODO: Check why a symlinks farm prefix can not be used.
 APP_MAIN_PREFIX_TYPE='none'
@@ -131,6 +140,7 @@ APP_MAIN_ICON='gfx/exe_icon.bmp'
 
 PACKAGES_LIST='
 PKG_BIN
+PKG_DATA_MODELS_SHIPS
 PKG_DATA_MODELS
 PKG_DATA'
 
@@ -141,6 +151,10 @@ PKG_DATA_MODELS_ID="${PKG_DATA_ID}-models"
 PKG_DATA_MODELS_DESCRIPTION="${PKG_DATA_DESCRIPTION} - models"
 PKG_DATA_DEPS="${PKG_DATA_DEPS:-} $PKG_DATA_MODELS_ID"
 
+PKG_DATA_MODELS_SHIPS_ID="${PKG_DATA_MODELS_ID}-ships"
+PKG_DATA_MODELS_SHIPS_DESCRIPTION="${PKG_DATA_MODELS_DESCRIPTION} - ships"
+PKG_DATA_MODELS_DEPS="${PKG_DATA_MODELS_DEPS:-} $PKG_DATA_MODELS_SHIPS_ID"
+
 PKG_BIN_ARCH='64'
 PKG_BIN_DEPS="$PKG_DATA_ID"
 PKG_BIN_DEPENDENCIES_LIBRARIES='
@@ -151,7 +165,6 @@ libGL.so.1
 libm.so.6
 libpthread.so.0
 libresolv.so.2
-librt.so.1
 libstdc++.so.6
 libuuid.so.1
 libX11.so.6
@@ -195,21 +208,21 @@ archive_extraction_default
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	# Delete unwanted files
+	## Prevent inclusion of the Paradox launcher.
 	rm --force --recursive \
-		'pdx_browser'
+		'libPDXBrowser_IPC.so' \
+		launcher-* \
+		pdx_*
 )
 
 # Include game data
 
-set_current_package 'PKG_DATA'
-icons_inclusion
+content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
 # Write launchers
 
-set_current_package 'PKG_BIN'
-launchers_write
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
