@@ -7,9 +7,9 @@ set -o errexit
 # The Settlers 2
 ###
 
-script_version=20230925.1
+script_version=20240413.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.26'
+PLAYIT_COMPATIBILITY_LEVEL='2.28'
 
 GAME_ID='the-settlers-2'
 GAME_NAME='The Settlers Ⅱ'
@@ -180,7 +180,9 @@ APP_SETUP_NAME="$GAME_NAME - Setup"
 APP_SETUP_CAT='Settings'
 APP_SETUP_ICON="$APP_MAIN_ICON"
 
-PACKAGES_LIST='PKG_COMMON PKG_MAIN'
+PACKAGES_LIST='
+PKG_COMMON
+PKG_MAIN'
 
 PKG_COMMON_ID="${GAME_ID}-common"
 PKG_COMMON_DESCRIPTION='common data'
@@ -227,20 +229,21 @@ archive_extraction_default
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
+	## Convert all file paths to uppercase.
 	toupper .
 
-	# Enforce disk image name
+	## Enforce disk image name.
 	if [ -e 'SETTLERS2.INST' ]; then
 		mv 'SETTLERS2.INST' "$GAME_IMAGE"
 	fi
 
-	# Ensure case consistency in disk image table of contents
+	## Ensure case consistency in disk image table of contents.
 	sed_pattern='settlers2.gog'
 	sed_replacement='SETTLERS2.GOG'
 	sed_expression="s/${sed_pattern}/${sed_replacement}/i"
 	sed --in-place --expression="$sed_expression" "$GAME_IMAGE"
 
-	# Enforce icon name and path
+	## Enforce icon name and path.
 	for icon_path in \
 		'GOGGAME-1207658786.ICO' \
 		'GFW_HIGH.ICO'
@@ -252,26 +255,18 @@ archive_extraction_default
 	done
 )
 
-# Include game icons
-
-PKG='PKG_COMMON'
-icons_inclusion
-
 # Include game data
 
+content_inclusion_icons 'PKG_COMMON'
 content_inclusion_default
 
 # Write launchers
 
-PKG='PKG_MAIN'
-launchers_write
+launchers_generation 'PKG_MAIN'
 
 # Build packages
 
 packages_generation
-
-# Print instructions
-
 print_instructions
 
 # Clean up
