@@ -7,9 +7,9 @@ set -o errexit
 # Torchlight 1
 ###
 
-script_version=20230925.1
+script_version=20240416.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.26'
+PLAYIT_COMPATIBILITY_LEVEL='2.28'
 
 GAME_ID='torchlight-1'
 GAME_NAME='Torchlight'
@@ -46,12 +46,14 @@ CONTENT_DOC_DATA_FILES='
 *.pdf'
 
 WINE_PERSISTENT_DIRECTORIES='
-users/${USER}/Application Data/runic games/torchlight'
+users/${USER}/AppData/Roaming/runic games/torchlight'
 
 APP_MAIN_EXE='torchlight.exe'
 APP_MAIN_ICON='torchlight.ico'
 
-PACKAGES_LIST='PKG_BIN PKG_DATA'
+PACKAGES_LIST='
+PKG_BIN
+PKG_DATA'
 
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
@@ -90,32 +92,24 @@ archive_extraction_default
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	# Drop unwanted files
+	## Drop unwanted files.
 	rm --force --recursive \
 		'commonappdata' \
 		'tmp'
 )
 
-# Include game icons
-
-PKG='PKG_DATA'
-icons_inclusion
-
 # Include game data
 
+content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
 # Write launchers
 
-PKG='PKG_BIN'
-launchers_write
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
 packages_generation
-
-# Print instructions
-
 print_instructions
 
 # Clean up
