@@ -11,9 +11,9 @@ set -o errexit
 # - Bastard's Wound
 ###
 
-script_version=20230926.1
+script_version=20240416.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.26'
+PLAYIT_COMPATIBILITY_LEVEL='2.28'
 
 GAME_ID='tyranny'
 GAME_NAME='Tyranny'
@@ -102,8 +102,8 @@ archive_extraction_default
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	# Bastard's Wound - Delete duplicated files already provided by the base game
-	case "$(context_archive)" in
+	## Bastard's Wound - Delete duplicated files already provided by the base game.
+	case "$(current_archive)" in
 		('ARCHIVE_BASE_WOUND_'*)
 			rm \
 				'Tyranny_Data/bundles/st_vx1_ar_0901_bastardswound_ent_01.unity3d' \
@@ -330,9 +330,6 @@ content_inclusion_default
 # Build packages
 
 packages_generation
-
-# Print instructions
-
 print_instructions
 
 # Clean up
