@@ -10,9 +10,9 @@ set -o errexit
 # Worms: Armageddon
 ###
 
-script_version=20230927.1
+script_version=20240416.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.26'
+PLAYIT_COMPATIBILITY_LEVEL='2.28'
 
 GAME_ID='worms-armageddon'
 GAME_NAME='Worms: Armageddon'
@@ -73,7 +73,9 @@ APP_MAIN_PRERUN='# Create required empty file prior to game run
 touch steam.dat
 '
 
-PACKAGES_LIST='PKG_BIN PKG_DATA'
+PACKAGES_LIST='
+PKG_BIN
+PKG_DATA'
 
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
@@ -119,26 +121,18 @@ archive_extraction_default
 		'tmp'
 )
 
-# Include game icons
-
-PKG='PKG_DATA'
-icons_inclusion
-
 # Include game data
 
+content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
 # Write launchers
 
-PKG='PKG_BIN'
-launchers_write
+launchers_generation 'PKG_BIN'
 
 # Build packages
 
 packages_generation
-
-# Print instructions
-
 print_instructions
 
 # Clean up
